-- ############################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  5724-C01
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #   File Information: src/TEDW/tedw_apps_etl/gwl/pkg/v120/cdw/ddl/gwl_cdw_schema.sql, BEA_PAC, wls_dev, 2004.06.23A
-- #   Revision: 1.2
-- #   Date: 10/31/02 10:42:06
-- ############################################################################

---------
--- Host 
---------

--VE VIEW
create view GWL.ve_host (max_value) as
select max(c.comp_id) 
from TWG.cur_comp c
where c.comptyp_cd in ('IP_HOST', 'IP_INTERFACE', 
                       'TME_ENDPOINT', 'GWL_HOST')
;

--VD VIEW
create view GWL.vd_host(
 orig_host_id,
 host_name,
 cust_nm,
 centr_nm ) as
select
  c1.comp_id as orig_host_id,
  c1.comp_nm as host_name,  
  cu.cust_nm as cust_nm,
  ce.centr_nm as centr_nm 
 from  
  TWG.Cur_Comp c1, 
  TWG.Cust cu,
  TWG.Centr ce
where
  cu.cust_id=c1.cust_id and
  ce.centr_cd=c1.centr_cd and
  c1.comptyp_cd in ('IP_HOST', 'GWL_HOST', 'IP_INTERFACE', 'TME_ENDPOINT')
;  

--------------------
--- WebLogic Server 
--------------------

create table GWL.stg_Server_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view GWL.ve_Server_met (max_value) as
select max(metric_id) 
from GWL.stg_Server_met
;

-- VD VIEW
create view GWL.vd_Server_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 GWL.stg_Server_met d
;

-- VE VIEW
create view GWL.ve_Server (max_value) as
select max(c.comp_id) 
from TWG.cur_comp c
where c.comptyp_cd = 'GWL_SERVER' 
;

-- VD VIEW
create view GWL.vd_Server(
 orig_Server_id,
 ServerName,
 DomainName,
 ListenAddr,
 ListenPort) as
select
 c1.comp_id as orig_Server_id,
 ca1.compattr_val as ServerName,
 ca2.compattr_val as DomainName,
 value(min(ca3.compattr_val),'UNKNOWN') as ListenAddr,
 value(min(ca4.compattr_val),'UNKNOWN') as ListenPort
from
 TWG.cur_compattr ca1,
 TWG.cur_compattr ca2,
 TWG.cur_comp c1
 left outer join 
 TWG.cur_compattr ca3
   on c1.comp_id = ca3.comp_id and ca3.attrtyp_cd = 'GWL_LISTEN_ADDR',
 TWG.cur_comp c2
 left outer join 
 TWG.cur_compattr ca4
   on c2.comp_id = ca4.comp_id and ca4.attrtyp_cd = 'GWL_LISTEN_PORT'
where
 c1.comp_id=c2.comp_id and
 c1.comptyp_cd='GWL_SERVER' and
 c1.comp_id = ca1.comp_id and
 ca1.attrtyp_cd = 'NAME' and
 c1.comp_id = ca2.comp_id and
 ca2.attrtyp_cd = 'GWL_DOMAIN'
group by
 c1.comp_id, ca1.compattr_val, ca2.compattr_val 
 ;
 

--VE VIEW
create view GWL.ve_stg_Server_hr (max_value) as
select max(m.msmt_id) 
from   TWG.cur_comp c, TWG.msmt m
where  c.comptyp_cd = 'GWL_SERVER'
and    c.comp_id = m.comp_id
;

-- VF VIEW
create view GWL.vf_stg_Server_hr (msmt_id, orig_Server_id, Sv_Version, 
 orig_host_id, 
 orig_metric_id, meas_hour, min_value, max_value, avg_value, 
 total_value, sample_count ) as
select 
 m.msmt_id as msmt_id,
 m.comp_id as orig_Server_id,
 value(min(ca1.compattr_val),'UNKNOWN') as Sv_Version,
 min(c1.comp_corr_id) as orig_host_id,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 TWG.msmt m
 left outer join 
 TWG.cur_compattr ca1
   on m.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'VERSION',
 TWG.msmt m2
 inner join 
 TWG.cur_comp c1
   on c1.comp_id=m2.comp_id and c1.comptyp_cd = 'GWL_SERVER'
where 
  m.tmsum_cd='H' and
  m.msmt_id = m2.msmt_id 
group by 
  m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd, 
  m.msmt_strt_dt,m.msmt_strt_tm
;    
--------------------
--- WebLogic JDBCCnxPl 
--------------------

create table GWL.stg_JDBCCnxPl_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view GWL.ve_JDBCCnxPl_met (max_value) as
select max(metric_id) 
from GWL.stg_JDBCCnxPl_met
;

-- VD VIEW
create view GWL.vd_JDBCCnxPl_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 GWL.stg_JDBCCnxPl_met d
;

-- VE VIEW
create view GWL.ve_JDBCCnxPl (max_value) as
select max(c.comp_id) 
from TWG.cur_comp c
where c.comptyp_cd = 'GWL_JDBC_CNXPL' 
;

-- VD VIEW
create view GWL.vd_JDBCCnxPl(
 orig_JDBCCnxPl_id,
 JDBCCnxName,
 PoolName
) as
select
 c1.comp_id as orig_JDBCCnxPl_id,
 c1.comp_nm as JDBCCnxName,
 value(min(ca1.compattr_val),'UNKNOWN') as PoolName
from
 TWG.cur_comp c1
 left outer join 
 TWG.cur_compattr ca1
   on c1.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'GWL_JDBC_POOL_NM'
 where
 c1.comptyp_cd='GWL_JDBC_CNXPL'
group by
 c1.comp_id, c1.comp_nm
 ;
 

--VE VIEW
create view GWL.ve_stg_JDBCCnxPl_hr (max_value) as
select max(m.msmt_id) 
from   TWG.cur_comp c, TWG.msmt m
where  c.comptyp_cd = 'GWL_JDBC_CNXPL'
and    c.comp_id = m.comp_id
;

-- VF VIEW
create view GWL.vf_stg_JDBCCnxPl_hr (msmt_id, orig_JDBCCnxPl_id,  
 VersJDBCDrv, orig_Server_id, Sv_Version,orig_host_id, 
 orig_metric_id, meas_hour, min_value, max_value, avg_value, 
 total_value, sample_count ) as
select 
 m.msmt_id as msmt_id,
 m.comp_id as orig_JDBCCnxPl_id,
 value(min(ca2.compattr_val),'UNKNOWN') as VersJDBCDrv,
 min(c1.comp_corr_id) as orig_Server_id,
 value(min(ca1.compattr_val),'UNKNOWN') as Sv_Version,
 min(c2.comp_corr_id) as orig_host_id,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 TWG.cur_comp c3
 left outer join 
 TWG.cur_compattr ca1
   on c3.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'VERSION',
 TWG.msmt m
 inner join 
 TWG.cur_comp c1
   on c1.comp_id=m.comp_id and c1.comptyp_cd = 'GWL_JDBC_CNXPL',
 TWG.cur_comp c4
 left outer join 
 TWG.cur_compattr ca2
   on c4.comp_id = ca2.comp_id and ca2.attrtyp_cd = 'GWL_VERS_JDBC_DRV',
 TWG.cur_comp c2  
where 
  m.tmsum_cd='H' and
  c1.comp_corr_id=c2.comp_id and
  c1.comp_id=c4.comp_id and
  c3.comp_id=c2.comp_id
group by 
  m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd, 
  m.msmt_strt_dt,m.msmt_strt_tm
;    

--------------------
--- WebLogic JMSCnx 
--------------------

create table GWL.stg_JMSCnx_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view GWL.ve_JMSCnx_met (max_value) as
select max(metric_id) 
from GWL.stg_JMSCnx_met
;

-- VD VIEW
create view GWL.vd_JMSCnx_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 GWL.stg_JMSCnx_met d
;

-- VE VIEW
create view GWL.ve_JMSCnx (max_value) as
select max(c.comp_id) 
from TWG.cur_comp c
where c.comptyp_cd = 'GWL_JMS_CNX' 
;

-- VD VIEW
create view GWL.vd_JMSCnx(
 orig_JMSCnx_id,
 JMSCnxName,
 ClientId
) as
select
 c1.comp_id as orig_JMSCnx_id,
 c1.comp_nm as JMSCnxName,
 value(min(ca1.compattr_val),'UNKNOWN') as ClientID
from
 TWG.cur_comp c1
 left outer join 
 TWG.cur_compattr ca1
   on c1.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'GWL_CLIENT_ID'
where
 c1.comptyp_cd='GWL_JMS_CNX' 
group by
 c1.comp_id, c1.comp_nm 
 ;
 

--VE VIEW
create view GWL.ve_stg_JMSCnx_hr (max_value) as
select max(m.msmt_id) 
from   TWG.cur_comp c, TWG.msmt m
where  c.comptyp_cd = 'GWL_JMS_CNX'
and    c.comp_id = m.comp_id
;

-- VF VIEW
create view GWL.vf_stg_JMSCnx_hr (msmt_id, orig_JMSCnx_id, 
 orig_Server_id, Sv_Version, orig_host_id, 
 orig_metric_id, meas_hour, min_value, max_value, avg_value, 
 total_value, sample_count ) as
select 
 m.msmt_id as msmt_id,
 m.comp_id as orig_JMSCnx_id,
 min(c1.comp_corr_id) as orig_Server_id,
 value(min(ca1.compattr_val),'UNKNOWN') as Sv_Version,
 min(c2.comp_corr_id) as orig_host_id,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 TWG.cur_comp c3
 left outer join 
 TWG.cur_compattr ca1
   on c3.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'VERSION',
 TWG.msmt m
 inner join 
 TWG.cur_comp c1
   on c1.comp_id=m.comp_id and c1.comptyp_cd = 'GWL_JMS_CNX',
 TWG.cur_comp c2  
where 
  m.tmsum_cd='H' and
  c1.comp_corr_id=c2.comp_id and
  c3.comp_id=c2.comp_id
group by 
  m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd, 
  m.msmt_strt_dt,m.msmt_strt_tm
;    

--------------------
--- WebLogic JMSSrv 
--------------------

create table GWL.stg_JMSSrv_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view GWL.ve_JMSSrv_met (max_value) as
select max(metric_id) 
from GWL.stg_JMSSrv_met
;

-- VD VIEW
create view GWL.vd_JMSSrv_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 GWL.stg_JMSSrv_met d
;

-- VE VIEW
create view GWL.ve_JMSSrv (max_value) as
select max(c.comp_id) 
from TWG.cur_comp c
where c.comptyp_cd = 'GWL_JMS_SV' 
;

-- VD VIEW
create view GWL.vd_JMSSrv(
 orig_JMSSrv_id,
 JMSSrvName
) as
select
 c1.comp_id as orig_JMSSrv_id,
 c1.comp_nm as JMSSrvName
from
 TWG.cur_comp c1
where
 c1.comptyp_cd='GWL_JMS_SV'
group by
 c1.comp_id, c1.comp_nm 
 ;
 

--VE VIEW
create view GWL.ve_stg_JMSSrv_hr (max_value) as
select max(m.msmt_id) 
from   TWG.cur_comp c, TWG.msmt m
where  c.comptyp_cd = 'GWL_JMS_SV'
and    c.comp_id = m.comp_id
;

-- VF VIEW
create view GWL.vf_stg_JMSSrv_hr (msmt_id, orig_JMSSrv_id,  
 orig_Server_id, Sv_Version, orig_host_id, 
 orig_metric_id, meas_hour, min_value, max_value, avg_value, 
 total_value, sample_count ) as
select 
 m.msmt_id as msmt_id,
 m.comp_id as orig_JMSSrv_id,
 min(c1.comp_corr_id) as orig_Server_id,
 value(min(ca1.compattr_val),'UNKNOWN') as Sv_Version,
 min(c2.comp_corr_id) as orig_host_id,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 TWG.cur_comp c3
 left outer join 
 TWG.cur_compattr ca1
   on c3.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'VERSION',
 TWG.msmt m
 inner join 
 TWG.cur_comp c1
   on c1.comp_id=m.comp_id and c1.comptyp_cd = 'GWL_JMS_SV',
 TWG.cur_comp c2  
where 
  m.tmsum_cd='H' and
  c1.comp_corr_id=c2.comp_id and
  c3.comp_id=c2.comp_id
group by 
  m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd, 
  m.msmt_strt_dt,m.msmt_strt_tm
;    

--------------------
--- WebLogic Appl 
--------------------

create table GWL.stg_Appl_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view GWL.ve_Appl_met (max_value) as
select max(metric_id) 
from GWL.stg_Appl_met
;

-- VD VIEW
create view GWL.vd_Appl_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 GWL.stg_Appl_met d
;

-- VE VIEW
create view GWL.ve_Appl (max_value) as
select max(c.comp_id) 
from TWG.cur_comp c
where c.comptyp_cd = 'GWL_APPL' 
;

-- VD VIEW
create view GWL.vd_Appl(
 orig_Appl_id,
 ApplName
) as
select
 c1.comp_id as orig_Appl_id,
 c1.comp_nm as ApplName
from
 TWG.cur_comp c1
where
 c1.comptyp_cd='GWL_APPL'
group by
 c1.comp_id, c1.comp_nm 
 ;
 

--VE VIEW
create view GWL.ve_stg_Appl_hr (max_value) as
select max(m.msmt_id) 
from   TWG.cur_comp c, TWG.msmt m
where  c.comptyp_cd = 'GWL_APPL'
and    c.comp_id = m.comp_id
;

-- VF VIEW
create view GWL.vf_stg_Appl_hr (msmt_id, orig_Appl_id,  
 orig_Server_id, Sv_Version, orig_host_id, 
 orig_metric_id, meas_hour, min_value, max_value, avg_value, 
 total_value, sample_count ) as
select 
 m.msmt_id as msmt_id,
 m.comp_id as orig_Appl_id,
 min(c1.comp_corr_id) as orig_Server_id,
 value(min(ca1.compattr_val),'UNKNOWN') as Sv_Version,
 min(c2.comp_corr_id) as orig_host_id,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 TWG.cur_comp c3
 left outer join 
 TWG.cur_compattr ca1
   on c3.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'VERSION',
 TWG.msmt m
 inner join 
 TWG.cur_comp c1
   on c1.comp_id=m.comp_id and c1.comptyp_cd = 'GWL_APPL',
 TWG.cur_comp c2  
where 
  m.tmsum_cd='H' and
  c1.comp_corr_id=c2.comp_id and
  c3.comp_id=c2.comp_id
group by 
  m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd, 
  m.msmt_strt_dt,m.msmt_strt_tm
;    

--------------------
--- WebLogic Ex_Qu 
--------------------

create table GWL.stg_Ex_Qu_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view GWL.ve_Ex_Qu_met (max_value) as
select max(metric_id) 
from GWL.stg_Ex_Qu_met
;

-- VD VIEW
create view GWL.vd_Ex_Qu_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 GWL.stg_Ex_Qu_met d
;

-- VE VIEW
create view GWL.ve_Ex_Qu (max_value) as
select max(c.comp_id) 
from TWG.cur_comp c
where c.comptyp_cd = 'GWL_EX_QU' 
;

-- VD VIEW
create view GWL.vd_Ex_Qu(
 orig_Ex_Qu_id,
 ExQuName
) as
select
 c1.comp_id as orig_Ex_Qu_id,
 c1.comp_nm as ExQuName
from
 TWG.cur_comp c1
where
 c1.comptyp_cd='GWL_EX_QU'
group by
 c1.comp_id, c1.comp_nm 
 ;
 

--VE VIEW
create view GWL.ve_stg_Ex_Qu_hr (max_value) as
select max(m.msmt_id) 
from   TWG.cur_comp c, TWG.msmt m
where  c.comptyp_cd = 'GWL_EX_QU'
and    c.comp_id = m.comp_id
;

-- VF VIEW
create view GWL.vf_stg_Ex_Qu_hr (msmt_id, orig_Ex_Qu_id,  
 orig_Server_id, Sv_Version, orig_host_id, 
 orig_metric_id, meas_hour, min_value, max_value, avg_value, 
 total_value, sample_count ) as
select 
 m.msmt_id as msmt_id,
 m.comp_id as orig_Ex_Qu_id,
 min(c1.comp_corr_id) as orig_Server_id,
 value(min(ca1.compattr_val),'UNKNOWN') as Sv_Version,
 min(c2.comp_corr_id) as orig_host_id,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 TWG.cur_comp c3
 left outer join 
 TWG.cur_compattr ca1
   on c3.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'VERSION',
 TWG.msmt m
 inner join 
 TWG.cur_comp c1
   on c1.comp_id=m.comp_id and c1.comptyp_cd = 'GWL_EX_QU',
 TWG.cur_comp c2  
where 
  m.tmsum_cd='H' and
  c1.comp_corr_id=c2.comp_id and
  c3.comp_id=c2.comp_id
group by 
  m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd, 
  m.msmt_strt_dt,m.msmt_strt_tm
;    

--------------------
--- WebLogic Serv_Sec 
--------------------

create table GWL.stg_Serv_Sec_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view GWL.ve_Serv_Sec_met (max_value) as
select max(metric_id) 
from GWL.stg_Serv_Sec_met
;

-- VD VIEW
create view GWL.vd_Serv_Sec_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 GWL.stg_Serv_Sec_met d
;

-- VE VIEW
create view GWL.ve_Serv_Sec (max_value) as
select max(c.comp_id) 
from TWG.cur_comp c
where c.comptyp_cd = 'GWL_SV_SEC' 
;

-- VD VIEW
create view GWL.vd_Serv_Sec(
 orig_Serv_Sec_id,
 SevSecName
) as
select
 c1.comp_id as orig_Serv_Sec_id,
 c1.comp_nm as SevSecName
from
 TWG.cur_comp c1
where
 c1.comptyp_cd='GWL_SV_SEC'
group by
 c1.comp_id, c1.comp_nm 
 ;
 

--VE VIEW
create view GWL.ve_stg_Serv_Sec_hr (max_value) as
select max(m.msmt_id) 
from   TWG.cur_comp c, TWG.msmt m
where  c.comptyp_cd = 'GWL_SV_SEC'
and    c.comp_id = m.comp_id
;

-- VF VIEW
create view GWL.vf_stg_Serv_Sec_hr (msmt_id, orig_Serv_Sec_id,  
 orig_Server_id, Sv_Version, orig_host_id, 
 orig_metric_id, meas_hour, min_value, max_value, avg_value, 
 total_value, sample_count ) as
select 
 m.msmt_id as msmt_id,
 m.comp_id as orig_Serv_Sec_id,
 min(c1.comp_corr_id) as orig_Server_id,
 value(min(ca1.compattr_val),'UNKNOWN') as Sv_Version,
 min(c2.comp_corr_id) as orig_host_id,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 TWG.cur_comp c3
 left outer join 
 TWG.cur_compattr ca1
   on c3.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'VERSION',
 TWG.msmt m
 inner join 
 TWG.cur_comp c1
   on c1.comp_id=m.comp_id and c1.comptyp_cd = 'GWL_SV_SEC',
 TWG.cur_comp c2  
where 
  m.tmsum_cd='H' and
  c1.comp_corr_id=c2.comp_id and
  c3.comp_id=c2.comp_id
group by 
  m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd, 
  m.msmt_strt_dt,m.msmt_strt_tm
;    

--------------------
--- WebLogic Log_Bdct 
--------------------

create table GWL.stg_Log_Bdct_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view GWL.ve_Log_Bdct_met (max_value) as
select max(metric_id) 
from GWL.stg_Log_Bdct_met
;

-- VD VIEW
create view GWL.vd_Log_Bdct_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 GWL.stg_Log_Bdct_met d
;

-- VE VIEW
create view GWL.ve_Log_Bdct (max_value) as
select max(c.comp_id) 
from TWG.cur_comp c
where c.comptyp_cd = 'GWL_LG_BCAST' 
;

-- VD VIEW
create view GWL.vd_Log_Bdct(
 orig_Log_Bdct_id,
 LogBdctName
) as
select
 c1.comp_id as orig_Log_Bdct_id,
 c1.comp_nm as LogBdctName
from
 TWG.cur_comp c1
where
 c1.comptyp_cd='GWL_LG_BCAST'
group by
 c1.comp_id, c1.comp_nm 
 ;
 

--VE VIEW
create view GWL.ve_stg_Log_Bdct_hr (max_value) as
select max(m.msmt_id) 
from   TWG.cur_comp c, TWG.msmt m
where  c.comptyp_cd = 'GWL_LG_BCAST'
and    c.comp_id = m.comp_id
;

-- VF VIEW
create view GWL.vf_stg_Log_Bdct_hr (msmt_id, orig_Log_Bdct_id,  
 orig_Server_id, Sv_Version, orig_host_id, 
 orig_metric_id, meas_hour, min_value, max_value, avg_value, 
 total_value, sample_count ) as
select 
 m.msmt_id as msmt_id,
 m.comp_id as orig_Log_Bdct_id,
 min(c1.comp_corr_id) as orig_Server_id,
 value(min(ca1.compattr_val),'UNKNOWN') as Sv_Version,
 min(c2.comp_corr_id) as orig_host_id,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 TWG.cur_comp c3
 left outer join 
 TWG.cur_compattr ca1
   on c3.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'VERSION',
 TWG.msmt m
 inner join 
 TWG.cur_comp c1
   on c1.comp_id=m.comp_id and c1.comptyp_cd = 'GWL_LG_BCAST',
 TWG.cur_comp c2  
where 
  m.tmsum_cd='H' and
  c1.comp_corr_id=c2.comp_id and
  c3.comp_id=c2.comp_id
group by 
  m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd, 
  m.msmt_strt_dt,m.msmt_strt_tm
;    

--------------------
--- WebLogic JTA 
--------------------

create table GWL.stg_JTA_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view GWL.ve_JTA_met (max_value) as
select max(metric_id) 
from GWL.stg_JTA_met
;

-- VD VIEW
create view GWL.vd_JTA_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 GWL.stg_JTA_met d
;

-- VE VIEW
create view GWL.ve_JTA (max_value) as
select max(c.comp_id) 
from TWG.cur_comp c
where c.comptyp_cd = 'GWL_JTA' 
;

-- VD VIEW
create view GWL.vd_JTA(
 orig_JTA_id,
 JTAName
) as
select
 c1.comp_id as orig_JTA_id,
 c1.comp_nm as JTAName
from
 TWG.cur_comp c1
where
 c1.comptyp_cd='GWL_JTA'
group by
 c1.comp_id, c1.comp_nm 
 ;
 

--VE VIEW
create view GWL.ve_stg_JTA_hr (max_value) as
select max(m.msmt_id) 
from   TWG.cur_comp c, TWG.msmt m
where  c.comptyp_cd = 'GWL_JTA'
and    c.comp_id = m.comp_id
;

-- VF VIEW
create view GWL.vf_stg_JTA_hr (msmt_id, orig_JTA_id,  
 orig_Server_id, Sv_version, orig_host_id, 
 orig_metric_id, meas_hour, min_value, max_value, avg_value, 
 total_value, sample_count ) as
select 
 m.msmt_id as msmt_id,
 m.comp_id as orig_JTA_id,
 min(c1.comp_corr_id) as orig_Server_id,
 value(min(ca1.compattr_val),'UNKNOWN') as Sv_Version,
 min(c2.comp_corr_id) as orig_host_id,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 TWG.cur_comp c3
 left outer join 
 TWG.cur_compattr ca1
   on c3.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'VERSION',
 TWG.msmt m
 inner join 
 TWG.cur_comp c1
   on c1.comp_id=m.comp_id and c1.comptyp_cd = 'GWL_JTA',
 TWG.cur_comp c2  
where 
  m.tmsum_cd='H' and
  c1.comp_corr_id=c2.comp_id and
  c3.comp_id=c2.comp_id
group by 
  m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd, 
  m.msmt_strt_dt,m.msmt_strt_tm
;    

--------------------
--- WebLogic JVM 
--------------------

create table GWL.stg_JVM_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view GWL.ve_JVM_met (max_value) as
select max(metric_id) 
from GWL.stg_JVM_met
;

-- VD VIEW
create view GWL.vd_JVM_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 GWL.stg_JVM_met d
;

-- VE VIEW
create view GWL.ve_JVM (max_value) as
select max(c.comp_id) 
from TWG.cur_comp c
where c.comptyp_cd = 'GWL_JVM' 
;

-- VD VIEW
create view GWL.vd_JVM(
 orig_JVM_id,
 JVMName
) as
select
 c1.comp_id as orig_JVM_id,
 c1.comp_nm as JVMName
from
 TWG.cur_comp c1
where
 c1.comptyp_cd='GWL_JVM' 
group by
 c1.comp_id, c1.comp_nm
 ;
 

--VE VIEW
create view GWL.ve_stg_JVM_hr (max_value) as
select max(m.msmt_id) 
from   TWG.cur_comp c, TWG.msmt m
where  c.comptyp_cd = 'GWL_JVM'
and    c.comp_id = m.comp_id
;

-- VF VIEW
create view GWL.vf_stg_JVM_hr (msmt_id, orig_JVM_id, JVMVersion, 
 JVMVendor, orig_Server_id, Sv_Version, orig_host_id, 
 orig_metric_id, meas_hour, min_value, max_value, avg_value, 
 total_value, sample_count ) as
select 
 m.msmt_id as msmt_id,
 m.comp_id as orig_JVM_id,
 value(min(ca1.compattr_val),'UNKNOWN') as JVMVersion,
 value(min(ca2.compattr_val),'UNKNOWN') as JVMVendor,
 min(c1.comp_corr_id) as orig_Server_id,
 value(min(ca3.compattr_val),'UNKNOWN') as Sv_Version,
 min(c2.comp_corr_id) as orig_host_id,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 TWG.cur_comp c3
 left outer join 
 TWG.cur_compattr ca3
   on c3.comp_id = ca3.comp_id and ca3.attrtyp_cd = 'VERSION',
 TWG.msmt m
 left outer join 
 TWG.cur_compattr ca1
   on m.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'VERSION',
 TWG.msmt m2
 left outer join 
 TWG.cur_compattr ca2
   on m2.comp_id = ca2.comp_id and ca2.attrtyp_cd = 'GWL_JVM_VENDOR',
 TWG.msmt m3
 inner join 
 TWG.cur_comp c1
   on c1.comp_id=m3.comp_id and c1.comptyp_cd = 'GWL_JVM',
 TWG.cur_comp c2  
where 
  m.tmsum_cd='H' and
  m.msmt_id = m2.msmt_id and
  m.msmt_id = m3.msmt_id and 
  c1.comp_corr_id=c2.comp_id and
  c3.comp_id=c2.comp_id
group by 
  m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd, 
  m.msmt_strt_dt,m.msmt_strt_tm
;    

--------------------
--- WebLogic Tx_Res 
--------------------

create table GWL.stg_Tx_Res_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view GWL.ve_Tx_Res_met (max_value) as
select max(metric_id) 
from GWL.stg_Tx_Res_met
;

-- VD VIEW
create view GWL.vd_Tx_Res_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 GWL.stg_Tx_Res_met d
;

-- VE VIEW
create view GWL.ve_Tx_Res (max_value) as
select max(c.comp_id) 
from TWG.cur_comp c
where c.comptyp_cd = 'GWL_TX_RES' 
;

-- VD VIEW
create view GWL.vd_Tx_Res(
 orig_Tx_Res_id,
 TxResName
) as
select
 c1.comp_id as orig_Tx_Res_id,
 c1.comp_nm as TxResName
from
 TWG.cur_comp c1
where
 c1.comptyp_cd='GWL_TX_RES' 
group by
 c1.comp_id, c1.comp_nm
 ;
 

--VE VIEW
create view GWL.ve_stg_Tx_Res_hr (max_value) as
select max(m.msmt_id) 
from   TWG.cur_comp c, TWG.msmt m
where  c.comptyp_cd = 'GWL_TX_RES'
and    c.comp_id = m.comp_id
;

-- VF VIEW
create view GWL.vf_stg_Tx_Res_hr (msmt_id, orig_Tx_Res_id,  
 orig_Server_id, Sv_Version, orig_JTA_id, orig_host_id, 
 orig_metric_id, meas_hour, min_value, max_value, avg_value, 
 total_value, sample_count ) as
select 
 m.msmt_id as msmt_id,
 m.comp_id as orig_Tx_Res_id,
 min(c2.comp_corr_id) as orig_Server_id,
 value(min(ca3.compattr_val),'UNKNOWN') as Sv_Version,
 min(c1.comp_corr_id) as orig_JTA_id,
 min(c3.comp_corr_id) as orig_host_id,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 TWG.cur_comp c4
 left outer join 
 TWG.cur_compattr ca3
   on c4.comp_id = ca3.comp_id and ca3.attrtyp_cd = 'VERSION',
 TWG.msmt m
 inner join 
 TWG.cur_comp c1
   on c1.comp_id=m.comp_id and c1.comptyp_cd = 'GWL_Tx_Res',
 TWG.cur_comp c2,
 TWG.cur_comp c3
where 
  m.tmsum_cd='H' and
  c1.comp_corr_id=c2.comp_id and
  c2.comp_corr_id=c3.comp_id and
  c4.comp_id=c3.comp_id
group by 
  m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd, 
  m.msmt_strt_dt,m.msmt_strt_tm
;    

--------------------
--- WebLogic JMS_Dest 
--------------------

create table GWL.stg_JMS_Dest_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view GWL.ve_JMS_Dest_met (max_value) as
select max(metric_id) 
from GWL.stg_JMS_Dest_met
;

-- VD VIEW
create view GWL.vd_JMS_Dest_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 GWL.stg_JMS_Dest_met d
;

-- VE VIEW
create view GWL.ve_JMS_Dest (max_value) as
select max(c.comp_id) 
from TWG.cur_comp c
where c.comptyp_cd = 'GWL_JMS_DEST' 
;

-- VD VIEW
create view GWL.vd_JMS_Dest(
 orig_JMS_Dest_id,
 JMSDestName,
 JMSDestType
) as
select
 c1.comp_id as orig_JMS_Dest_id,
 c1.comp_nm as JMSDestName,
 value(min(ca1.compattr_val),'UNKNOWN') as JMSDestType
from
 TWG.cur_comp c1
 left outer join 
 TWG.cur_compattr ca1
   on c1.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'GWL_DEST_TYPE'
where
 c1.comptyp_cd='GWL_JMS_DEST' 
group by
 c1.comp_id, c1.comp_nm 
 ;
 

--VE VIEW
create view GWL.ve_stg_JMS_Dest_hr (max_value) as
select max(m.msmt_id) 
from   TWG.cur_comp c, TWG.msmt m
where  c.comptyp_cd = 'GWL_JMS_DEST'
and    c.comp_id = m.comp_id
;

-- VF VIEW
create view GWL.vf_stg_JMS_Dest_hr (msmt_id, orig_JMS_Dest_id, 
 orig_Server_id, Sv_Version, orig_JMSSrv_id, orig_host_id, 
 orig_metric_id, meas_hour, min_value, max_value, avg_value, 
 total_value, sample_count ) as
select 
 m.msmt_id as msmt_id,
 m.comp_id as orig_JMS_Dest_id,
 min(c2.comp_corr_id) as orig_Server_id,
 value(min(ca1.compattr_val),'UNKNOWN') as Sv_Version,
 min(c1.comp_corr_id) as orig_JMSSrv_id,
 min(c3.comp_corr_id) as orig_host_id,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 TWG.cur_comp c4
 left outer join 
 TWG.cur_compattr ca1
   on c4.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'VERSION', 
 TWG.msmt m
 inner join 
 TWG.cur_comp c1
   on c1.comp_id=m.comp_id and c1.comptyp_cd = 'GWL_JMS_DEST',
 TWG.cur_comp c2,
 TWG.cur_comp c3
where 
  m.tmsum_cd='H' and
  c1.comp_corr_id=c2.comp_id and
  c2.comp_corr_id=c3.comp_id and
  c4.comp_id=c3.comp_id
group by 
  m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd, 
  m.msmt_strt_dt,m.msmt_strt_tm
;    

--------------------
--- WebLogic Cnt_Comp 
--------------------

create table GWL.stg_Cnt_Comp_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view GWL.ve_Cnt_Comp_met (max_value) as
select max(metric_id) 
from GWL.stg_Cnt_Comp_met
;

-- VD VIEW
create view GWL.vd_Cnt_Comp_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 GWL.stg_Cnt_Comp_met d
;

-- VE VIEW
create view GWL.ve_Cnt_Comp (max_value) as
select max(c.comp_id) 
from TWG.cur_comp c
where c.comptyp_cd = 'GWL_CNTOR_COMP' 
;

-- VD VIEW
create view GWL.vd_Cnt_Comp(
 orig_Cnt_Comp_id,
 CntCompName,
 DisplayName,
 CntFactName,
 PoolName
 ) as
select
 c1.comp_id as orig_Cnt_Comp_id,
 c1.comp_nm as CntCompName,
 value(min(ca1.compattr_val),'UNKNOWN') as DisplayName,
 value(min(ca2.compattr_val),'UNKNOWN') as CntFactName,
 value(min(ca3.compattr_val),'UNKNOWN') as PoolName
from
 TWG.cur_comp c1
 left outer join 
 TWG.cur_compattr ca1
   on c1.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'GWL_CNT_DISP_NM',
 TWG.cur_comp c2
 left outer join 
 TWG.cur_compattr ca2
   on c2.comp_id = ca2.comp_id and ca2.attrtyp_cd = 'GWL_CNX_FACT_NM',
 TWG.cur_comp c3
 left outer join 
 TWG.cur_compattr ca3
   on c3.comp_id = ca3.comp_id and ca3.attrtyp_cd = 'GWL_CC_POOL_NM'
where
 c1.comptyp_cd='GWL_CNTOR_COMP' 
group by
 c1.comp_id, c1.comp_nm
 ;
 

--VE VIEW
create view GWL.ve_stg_Cnt_Comp_hr (max_value) as
select max(m.msmt_id) 
from   TWG.cur_comp c, TWG.msmt m
where  c.comptyp_cd = 'GWL_CNTOR_COMP'
and    c.comp_id = m.comp_id
;

-- VF VIEW
create view GWL.vf_stg_Cnt_Comp_hr (msmt_id, orig_Cnt_Comp_id,
 orig_Server_id, Sv_Version, orig_Appl_id, orig_host_id, 
 orig_metric_id, meas_hour, min_value, max_value, avg_value, 
 total_value, sample_count ) as
select 
 m.msmt_id as msmt_id,
 m.comp_id as orig_Cnt_Comp_id,
 min(c2.comp_corr_id) as orig_Server_id,
 value(min(ca1.compattr_val),'UNKNOWN') as Sv_Version,
 min(c1.comp_corr_id) as orig_Appl_id,
 min(c3.comp_corr_id) as orig_host_id,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 TWG.cur_comp c4
 left outer join 
 TWG.cur_compattr ca1
   on c4.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'VERSION', 
 TWG.msmt m
 inner join 
 TWG.cur_comp c1
   on c1.comp_id=m.comp_id and c1.comptyp_cd = 'GWL_CNTOR_COMP',
 TWG.cur_comp c2,
 TWG.cur_comp c3
where 
  m.tmsum_cd='H' and
  c1.comp_corr_id=c2.comp_id and
  c2.comp_corr_id=c3.comp_id and
  c4.comp_id=c3.comp_id
group by 
  m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd, 
  m.msmt_strt_dt,m.msmt_strt_tm
;    

--------------------
--- WebLogic EJB_Comp 
--------------------

create table GWL.stg_EJB_Comp_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view GWL.ve_EJB_Comp_met (max_value) as
select max(metric_id) 
from GWL.stg_EJB_Comp_met
;

-- VD VIEW
create view GWL.vd_EJB_Comp_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 GWL.stg_EJB_Comp_met d
;

-- VE VIEW
create view GWL.ve_EJB_Comp (max_value) as
select max(c.comp_id) 
from TWG.cur_comp c
where c.comptyp_cd = 'GWL_EJB_COMP' 
;

-- VD VIEW
create view GWL.vd_EJB_Comp(
 orig_EJB_Comp_id,
 EJBCompName
) as
select
 c1.comp_id as orig_EJB_Comp_id,
 c1.comp_nm as EJBCompName
from
 TWG.cur_comp c1
where
 c1.comptyp_cd='GWL_EJB_COMP'
group by
 c1.comp_id, c1.comp_nm 
 ;
 

--VE VIEW
create view GWL.ve_stg_EJB_Comp_hr (max_value) as
select max(m.msmt_id) 
from   TWG.cur_comp c, TWG.msmt m
where  c.comptyp_cd = 'GWL_EJB_COMP'
and    c.comp_id = m.comp_id
;

-- VF VIEW
create view GWL.vf_stg_EJB_Comp_hr (msmt_id, orig_EJB_Comp_id,  
 orig_Server_id, Sv_Version, orig_Appl_id, orig_host_id, 
 orig_metric_id, meas_hour, min_value, max_value, avg_value, 
 total_value, sample_count ) as
select 
 m.msmt_id as msmt_id,
 m.comp_id as orig_EJB_Comp_id,
 min(c2.comp_corr_id) as orig_Server_id,
 value(min(ca1.compattr_val),'UNKNOWN') as Sv_Version,
 min(c1.comp_corr_id) as orig_Appl_id,
 min(c3.comp_corr_id) as orig_host_id,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 TWG.cur_comp c4
 left outer join 
 TWG.cur_compattr ca1
   on c4.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'VERSION', 
 TWG.msmt m
 inner join 
 TWG.cur_comp c1
   on c1.comp_id=m.comp_id and c1.comptyp_cd = 'GWL_EJB_COMP',
 TWG.cur_comp c2,
 TWG.cur_comp c3
where 
  m.tmsum_cd='H' and
  c1.comp_corr_id=c2.comp_id and
  c2.comp_corr_id=c3.comp_id and
  c4.comp_id=c3.comp_id
group by 
  m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd, 
  m.msmt_strt_dt,m.msmt_strt_tm
;    

--------------------
--- WebLogic WAP_COMP 
--------------------

create table GWL.stg_WAP_COMP_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view GWL.ve_WAP_COMP_met (max_value) as
select max(metric_id) 
from GWL.stg_WAP_COMP_met
;

-- VD VIEW
create view GWL.vd_WAP_COMP_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 GWL.stg_WAP_COMP_met d
;

-- VE VIEW
create view GWL.ve_WAP_COMP (max_value) as
select max(c.comp_id) 
from TWG.cur_comp c
where c.comptyp_cd = 'GWL_WAP_COMP' 
;

-- VD VIEW
create view GWL.vd_WAP_COMP(
 orig_WAP_COMP_id,
 WAPCompName,
 SourceInfo
) as
select
 c1.comp_id as orig_WAP_COMP_id,
 c1.comp_nm as WAPCompName,
 value(min(ca1.compattr_val),'UNKNOWN') as SourceInfo
from
 TWG.cur_comp c1
 left outer join 
 TWG.cur_compattr ca1
   on c1.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'GWL_SRCE_INFO'
where
 c1.comptyp_cd='GWL_WAP_COMP' 
group by
 c1.comp_id, c1.comp_nm 
 ;
 

--VE VIEW
create view GWL.ve_stg_WAP_COMP_hr (max_value) as
select max(m.msmt_id) 
from   TWG.cur_comp c, TWG.msmt m
where  c.comptyp_cd = 'GWL_WAP_COMP'
and    c.comp_id = m.comp_id
;

-- VF VIEW
create view GWL.vf_stg_WAP_COMP_hr (msmt_id, orig_WAP_COMP_id, 
 orig_Server_id, Sv_Version, orig_Appl_id, orig_host_id, 
 orig_metric_id, meas_hour, min_value, max_value, avg_value, 
 total_value, sample_count ) as
select 
 m.msmt_id as msmt_id,
 m.comp_id as orig_WAP_COMP_id,
 min(c2.comp_corr_id) as orig_Server_id,
 value(min(ca1.compattr_val),'UNKNOWN') as Sv_Version,
 min(c1.comp_corr_id) as orig_Appl_id,
 min(c3.comp_corr_id) as orig_host_id,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 TWG.cur_comp c4
 left outer join 
 TWG.cur_compattr ca1
   on c4.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'VERSION',  
 TWG.msmt m
 inner join 
 TWG.cur_comp c1
   on c1.comp_id=m.comp_id and c1.comptyp_cd = 'GWL_WAP_COMP',
 TWG.cur_comp c2,
 TWG.cur_comp c3
where 
  m.tmsum_cd='H' and
  c1.comp_corr_id=c2.comp_id and
  c2.comp_corr_id=c3.comp_id and
  c4.comp_id=c3.comp_id
group by 
  m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd, 
  m.msmt_strt_dt,m.msmt_strt_tm
;    

--------------------
--- WebLogic EJB 
--------------------

create table GWL.stg_EJB_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view GWL.ve_EJB_met (max_value) as
select max(metric_id) 
from GWL.stg_EJB_met
;

-- VD VIEW
create view GWL.vd_EJB_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 GWL.stg_EJB_met d
;

-- VE VIEW
create view GWL.ve_EJB (max_value) as
select max(c.comp_id) 
from TWG.cur_comp c
where c.comptyp_cd = 'GWL_EJB' 
;

-- VD VIEW
create view GWL.vd_EJB(
 orig_EJB_id,
 EJBName
) as
select
 c1.comp_id as orig_EJB_id,
 c1.comp_nm as EJBName
from
 TWG.cur_comp c1
where
 c1.comptyp_cd='GWL_EJB'
group by
 c1.comp_id, c1.comp_nm 
 ;
 

--VE VIEW
create view GWL.ve_stg_EJB_hr (max_value) as
select max(m.msmt_id) 
from   TWG.cur_comp c, TWG.msmt m
where  c.comptyp_cd = 'GWL_EJB'
and    c.comp_id = m.comp_id
;

-- VF VIEW
create view GWL.vf_stg_EJB_hr (msmt_id, orig_EJB_id,  
 orig_Server_id, Sv_Version, orig_Appl_id, orig_EJB_Comp_id, orig_host_id, 
 orig_metric_id, meas_hour, min_value, max_value, avg_value, 
 total_value, sample_count ) as
select 
 m.msmt_id as msmt_id,
 m.comp_id as orig_EJB_id,
 min(c3.comp_corr_id) as orig_Server_id,
 value(min(ca1.compattr_val),'UNKNOWN') as Sv_Version,
 min(c2.comp_corr_id) as orig_Appl_id,
 min(c1.comp_corr_id) as orig_EJB_Comp_id,
 min(c4.comp_corr_id) as orig_host_id,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 TWG.cur_comp c5
 left outer join 
 TWG.cur_compattr ca1
   on c5.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'VERSION', 
 TWG.msmt m
 inner join 
 TWG.cur_comp c1
   on c1.comp_id=m.comp_id and c1.comptyp_cd = 'GWL_EJB',
 TWG.cur_comp c2,
 TWG.cur_comp c3,
 TWG.cur_comp c4
where 
  m.tmsum_cd='H' and
  c1.comp_corr_id=c2.comp_id and
  c2.comp_corr_id=c3.comp_id and
  c3.comp_corr_id=c4.comp_id and
  c5.comp_id=c4.comp_id
group by 
  m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd, 
  m.msmt_strt_dt,m.msmt_strt_tm
;    

--------------------
--- WebLogic Servlet 
--------------------

create table GWL.stg_Servlet_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view GWL.ve_Servlet_met (max_value) as
select max(metric_id) 
from GWL.stg_Servlet_met
;

-- VD VIEW
create view GWL.vd_Servlet_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 GWL.stg_Servlet_met d
;

-- VE VIEW
create view GWL.ve_Servlet (max_value) as
select max(c.comp_id) 
from TWG.cur_comp c
where c.comptyp_cd = 'GWL_SERVLET' 
;

-- VD VIEW
create view GWL.vd_Servlet(
 orig_Servlet_id,
 ServletName
) as
select
 c1.comp_id as orig_Servlet_id,
 c1.comp_nm as ServletName
from
 TWG.cur_comp c1
where
 c1.comptyp_cd='GWL_SERVLET' 
group by
 c1.comp_id, c1.comp_nm
 ;
 

--VE VIEW
create view GWL.ve_stg_Servlet_hr (max_value) as
select max(m.msmt_id) 
from   TWG.cur_comp c, TWG.msmt m
where  c.comptyp_cd = 'GWL_SERVLET'
and    c.comp_id = m.comp_id
;

-- VF VIEW
create view GWL.vf_stg_Servlet_hr (msmt_id, orig_Servlet_id, ContextPath, 
 ServletPath, orig_Server_id, Sv_Version, orig_Appl_id, orig_WAP_COMP_id, orig_host_id, 
 orig_metric_id, meas_hour, min_value, max_value, avg_value, 
 total_value, sample_count ) as
select 
 m.msmt_id as msmt_id,
 m.comp_id as orig_Servlet_id,
 value(min(ca1.compattr_val),'UNKNOWN') as ContextPath,
 value(min(ca2.compattr_val),'UNKNOWN') as ServletPath,
 min(c3.comp_corr_id) as orig_Server_id,
 value(min(ca4.compattr_val),'UNKNOWN') as Sv_Version,
 min(c2.comp_corr_id) as orig_Appl_id,
 min(c1.comp_corr_id) as orig_WAP_COMP_id,
 min(c4.comp_corr_id) as orig_host_id,
 m.msmttyp_id as orig_metric_id,
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour,
 min(m.msmt_min_val) as min_value,
 max(m.msmt_max_val) as max_value,
 avg(m.msmt_avg_val) as avg_value,
 sum(m.msmt_tot_val) as total_value,
 min(m.msmt_smpl_cnt)as sample_count
from
 TWG.cur_comp c5
 left outer join 
 TWG.cur_compattr ca4
   on c5.comp_id = ca4.comp_id and ca4.attrtyp_cd = 'VERSION', 
 TWG.msmt m
 left outer join 
 TWG.cur_compattr ca1
   on m.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'GWL_CONTEXT_PATH',
 TWG.msmt m2
 left outer join 
 TWG.cur_compattr ca2
   on m2.comp_id = ca2.comp_id and ca2.attrtyp_cd = 'GWL_SERVLET_PATH',
 TWG.msmt m3
 inner join 
 TWG.cur_comp c1
   on c1.comp_id=m3.comp_id and c1.comptyp_cd = 'GWL_SERVLET',
 TWG.cur_comp c2,  
 TWG.cur_comp c3,  
 TWG.cur_comp c4  
where 
  m.tmsum_cd='H' and
  m.msmt_id = m2.msmt_id and
  m.msmt_id = m3.msmt_id and 
  c1.comp_corr_id=c2.comp_id and
  c2.comp_corr_id=c3.comp_id and
  c3.comp_corr_id=c4.comp_id and
  c5.comp_id=c4.comp_id
group by 
  m.msmt_id, m.comp_id, m.msmttyp_id, m.tmsum_cd, 
  m.msmt_strt_dt,m.msmt_strt_tm
;    

