-- ############################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  5724-C01
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #   File Information: src/TEDW/tedw_apps_etl/gwl/pkg/v120/mart/ddl/gwl_mart_schema.sql, BEA_PAC, wls_dev, 2004.06.23A
-- #   Revision: 1.7
-- #   Date: 11/17/02 20:48:14
-- ############################################################################

-------------------------------------------------------
-- Prune tables
-------------------------------------------------------

CREATE TABLE GWL.Prune_Mart_Control (
Table_Name 	varchar(120) not null,
PMartC_Duration	decimal(8,0) not null
);


CREATE TABLE GWL.Prune_Mart_Log (
PMart_Run_DtTm 	timestamp not null,
Table_Name	varchar(30),
PMartC_Duration	decimal(8,0) not null,
Number_Pruned	decimal(8,0) not null
);

----------------------------
--- Dimension Table:  Host  
----------------------------

create table GWL.d_host (
 host_id                     integer        not null,
 host_name                   varchar(254)   not null,
 cust_nm                     varchar(120), 
 centr_nm                    varchar(120),
      primary key (host_id)
      );

-- Translation table      

create table GWL.t_host (
 orig_host_id                integer        not null,
 host_id		     integer,
 cdw_id		             integer        not null,		
 host_name                   varchar(254)   not null,
 cust_nm                     varchar(120), 
 centr_nm                    varchar(120),
      primary key (orig_host_id, cdw_id)
      );

--SEQUENCE      

create sequence gwl.host_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger gwl.host_i1
no cascade before insert on gwl.d_host  
referencing new as n for each row mode db2sql
set n.host_id = nextval for gwl.host_id_seq;

--------------------
--- WebLogic Server 
--------------------

---------------------------------
-- Dimension Table: Server Metric 
---------------------------------

create table GWL.d_Server_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254)   not null,
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- Translation table

create table GWL.t_Server_metric (
  orig_metric_id 		INTEGER not null,
  metric_id			INTEGER,
  cdw_id 			INTEGER not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			VARCHAR(254) not null,
  met_units 			VARCHAR(254) not null,
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--SEQUENCE      

create sequence GWL.svmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.svmt_i1
no cascade before insert on GWL.d_Server_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for GWL.svmt_id_seq;

-----------------------------
-- Dimension Table: Server 
-----------------------------

create table GWL.d_Server (
 Server_id            integer        not null,
 ServerName                varchar(254)   not null,
 DomainName                varchar(254)   not null,
 ListenAddr	       varchar(254) not null,
 ListenPort	       varchar(254) not null,
      primary key (Server_id));

-- Translation table

create table GWL.t_Server (
 orig_Server_id       integer        not null,
 Server_id		integer,
 cdw_id		       integer        not null,
 ServerName                varchar(254)   not null,
 DomainName                varchar(254)   not null,
 ListenAddr	       varchar(254) not null,
 ListenPort	       varchar(254) not null,
      primary key (orig_Server_id,cdw_id)
      );


--SEQUENCE      

create sequence GWL.serv_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.serv_i1
no cascade before insert on GWL.d_Server  
referencing new as n for each row mode db2sql
set n.Server_id = nextval for GWL.serv_id_seq;
      
     
-----------------------------
-- Dimension Table:Sv_Version 
-----------------------------

create table GWL.d_sv_Version (
 Sv_Version_id    	           integer        not null,
 sv_Version                   varchar(254)   not null,
      primary key (Sv_Version_id));

--SEQUENCE      

create sequence GWL.vers_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.vers_i1
no cascade before insert on GWL.d_sv_Version 
referencing new as n for each row mode db2sql
set n.Sv_Version_id = nextval for GWL.vers_id_seq;     
      
-----------------------------
-- Hourly Fact Table: Server 
-----------------------------

create table GWL.f_Server_hour (
 Server_id                integer        not null,
 Sv_Version_id         	   integer        not null, 
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           integer,
       primary key (Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_hour)
       );

create index gwl.f_serv_hr1 on GWL.f_Server_hour (Server_id);
create index gwl.f_serv_hr2 on GWL.f_Server_hour (Sv_Version_id);
create index gwl.f_serv_hr3 on GWL.f_Server_hour (host_id);
create index gwl.f_serv_hr4 on GWL.f_Server_hour (metric_id);
create index gwl.f_serv_hr5 on GWL.f_Server_hour (meas_hour);

Alter table GWL.f_Server_hour
add constraint serv_1
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Server_hour
add constraint vers_1
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_Server_hour
add constraint host_1
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Server_hour
add constraint svmt_1
foreign key (metric_id)
references GWL.d_Server_metric (metric_id);       

--Staging hour fact table
create table GWL.stg_Server_hr (
 msmt_id		   integer	  not null,
 orig_Server_id            integer        not null,
 Sv_Version         	   varchar(254)   not null,
 orig_host_id              integer        not null,
 orig_metric_id            integer        not null,
 cdw_id			   integer        not null	,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           integer,
      primary key (msmt_id,cdw_id)
       );

-----------------------------
-- Daily Fact Table: Server 
-----------------------------

create table GWL.f_Server_day (
 Server_id                integer        not null,
 Sv_Version_id		   integer	  not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           integer,
       primary key (Server_id,
       Sv_Version_id, 
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_serv_day1 on GWL.f_Server_day (Server_id);
create index gwl.f_serv_day2 on GWL.f_Server_day (Sv_Version_id);
create index gwl.f_serv_day3 on GWL.f_Server_day (host_id);
create index gwl.f_serv_day4 on GWL.f_Server_day (metric_id);
create index gwl.f_serv_day5 on GWL.f_Server_day (meas_date);

Alter table GWL.f_Server_day
add constraint serv_2
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Server_day
add constraint vers_2
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_Server_day
add constraint host_2
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Server_day
add constraint svmt_2
foreign key (metric_id)
references GWL.d_Server_metric (metric_id);        

-----------------------------
-- Weekly Fact Table: Server 
-----------------------------

create table GWL.f_Server_week (
 Server_id                integer        not null,
 Sv_Version_id		   integer	  not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           integer,
        primary key (Server_id,
       Sv_Version_id, 
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_serv_wk1 on GWL.f_Server_week (Server_id);
create index gwl.f_serv_wk2 on GWL.f_Server_week (Sv_Version_id);
create index gwl.f_serv_wk3 on GWL.f_Server_week (host_id);
create index gwl.f_serv_wk4 on GWL.f_Server_week (metric_id);
create index gwl.f_serv_wk5 on GWL.f_Server_week (meas_date);

Alter table GWL.f_Server_week
add constraint serv_3
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Server_week
add constraint vers_3
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_Server_week
add constraint host_3
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Server_week
add constraint svmt_3
foreign key (metric_id)
references GWL.d_Server_metric (metric_id); 

-----------------------------
-- Monthly Fact Table: Server 
-----------------------------

create table GWL.f_Server_month (
 Server_id                integer        not null,
 Sv_Version_id		   integer	  not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           integer,
        primary key (Server_id,
       Sv_Version_id, 
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_serv_mo1 on GWL.f_Server_month (Server_id);
create index gwl.f_serv_mo2 on GWL.f_Server_month (Sv_Version_id);
create index gwl.f_serv_mo3 on GWL.f_Server_month (host_id);
create index gwl.f_serv_mo4 on GWL.f_Server_month (metric_id);
create index gwl.f_serv_mo5 on GWL.f_Server_month (meas_date);

Alter table GWL.f_Server_month
add constraint serv_4
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Server_month
add constraint vers_4
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_Server_month
add constraint host_4
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Server_month
add constraint svmt_4
foreign key (metric_id)
references GWL.d_Server_metric (metric_id);       


--------------------
--- WebLogic JDBCCnxPl 
--------------------

---------------------------------
-- Dimension Table: JDBCCnxPl Metric 
---------------------------------

create table GWL.d_JDBCCnxPl_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254)  not null,
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- Translation table

create table GWL.t_JDBCCnxPl_metric (
  orig_metric_id 		INTEGER not null,
  metric_id			INTEGER,
  cdw_id 			INTEGER not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			VARCHAR(254) not null,
  met_units 			VARCHAR(254) not null,
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--SEQUENCE      

create sequence GWL.cpmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.cpmt_i1
no cascade before insert on GWL.d_JDBCCnxPl_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for GWL.cpmt_id_seq;

-----------------------------
-- Dimension Table: JDBCCnxPl 
-----------------------------

create table GWL.d_JDBCCnxPl (
 JDBCCnxPl_id     	           integer        not null,
 JDBCCnxName                varchar(254)   not null,
 PoolName                varchar(254)   not null,
      primary key (JDBCCnxPl_id));

-- Translation table

create table GWL.t_JDBCCnxPl (
 orig_JDBCCnxPl_id            integer        not null,
 JDBCCnxPl_id			integer,
 cdw_id			   integer        not null,
 JDBCCnxName                varchar(254)   not null,
 PoolName                varchar(254)   not null,
      primary key (orig_JDBCCnxPl_id,cdw_id)
      );

--SEQUENCE      

create sequence GWL.cxpl_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.cxpl_i1
no cascade before insert on GWL.d_JDBCCnxPl  
referencing new as n for each row mode db2sql
set n.JDBCCnxPl_id = nextval for GWL.cxpl_id_seq;
      

-----------------------------
-- Dimension Table:JC_Version 
-----------------------------

create table GWL.d_jc_Version (
 Jc_Version_id    	           integer        not null,
 VersJDBCDrv                varchar(254)   not null,
      primary key (Jc_Version_id));

--SEQUENCE      

create sequence GWL.jcvs_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.jcvs_i1
no cascade before insert on GWL.d_Jc_Version 
referencing new as n for each row mode db2sql
set n.Jc_Version_id = nextval for GWL.jcvs_id_seq;     
      

-----------------------------
-- Hourly Fact Table: JDBCCnxPl 
-----------------------------

create table GWL.f_JDBCCnxPl_hour (
 JDBCCnxPl_id                 integer        not null,
 Jc_Version_id             integer	not null,
 Server_id		   integer	not null,
 Sv_Version_id          integer	  not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           integer,
       primary key (JDBCCnxPl_id,
       Jc_Version_id,
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_hour)
       );

create index gwl.f_cxpl_hr1 on GWL.f_JDBCCnxPl_hour (JDBCCnxPl_id);
create index gwl.f_cxpl_hr2 on GWL.f_JDBCCnxPl_hour (Jc_Version_id);
create index gwl.f_cxpl_hr3 on GWL.f_JDBCCnxPl_hour (Server_id);
create index gwl.f_cxpl_hr4 on GWL.f_JDBCCnxPl_hour (Sv_Version_id);
create index gwl.f_cxpl_hr5 on GWL.f_JDBCCnxPl_hour (host_id);
create index gwl.f_cxpl_hr6 on GWL.f_JDBCCnxPl_hour (metric_id);
create index gwl.f_cxpl_hr7 on GWL.f_JDBCCnxPl_hour (meas_hour);

Alter table GWL.f_JDBCCnxPl_hour
add constraint cxpl_1
foreign key (JDBCCnxPl_id)
references GWL.d_JDBCCnxPl (JDBCCnxPl_id);

Alter table GWL.f_JDBCCnxPl_hour
add constraint jcvs_1
foreign key (Jc_Version_id)
references GWL.d_Jc_Version (Jc_Version_id);

Alter table GWL.f_JDBCCnxPl_hour
add constraint serv_5
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JDBCCnxPl_hour
add constraint vers_5
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_JDBCCnxPl_hour
add constraint host_5
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JDBCCnxPl_hour
add constraint cpmt_1
foreign key (metric_id)
references GWL.d_JDBCCnxPl_metric (metric_id);       

--Staging hour fact table
create table GWL.stg_JDBCCnxPl_hr (
 msmt_id		   integer	  not null,
 orig_JDBCCnxPl_id         integer        not null,
 VersJDBCDrv               varchar(254)   not null,
 orig_Server_id		   integer	  not null,
 Sv_Version	 	   varchar(254)   not null, 
 orig_host_id              integer        not null,
 orig_metric_id            integer        not null,
 cdw_id			   integer        not null	,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           integer,
       primary key (msmt_id,cdw_id)
       );

-----------------------------
-- Daily Fact Table: JDBCCnxPl 
-----------------------------

create table GWL.f_JDBCCnxPl_day (
 JDBCCnxPl_id                 integer        not null,
 Jc_Version_id		   integer	not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           integer,
       primary key (JDBCCnxPl_id,
       Jc_Version_id,
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_cxpl_day1 on GWL.f_JDBCCnxPl_day (JDBCCnxPl_id);
create index gwl.f_cxpl_day2 on GWL.f_JDBCCnxPl_day (Jc_Version_id);
create index gwl.f_cxpl_day3 on GWL.f_JDBCCnxPl_day (Server_id);
create index gwl.f_cxpl_day4 on GWL.f_JDBCCnxPl_day (Sv_Version_id);
create index gwl.f_cxpl_day5 on GWL.f_JDBCCnxPl_day (host_id);
create index gwl.f_cxpl_day6 on GWL.f_JDBCCnxPl_day (metric_id);
create index gwl.f_cxpl_day7 on GWL.f_JDBCCnxPl_day (meas_date);

Alter table GWL.f_JDBCCnxPl_day
add constraint cxpl_2
foreign key (JDBCCnxPl_id)
references GWL.d_JDBCCnxPl (JDBCCnxPl_id);

Alter table GWL.f_JDBCCnxPl_day
add constraint jcvs_2
foreign key (Jc_Version_id)
references GWL.d_Jc_Version (Jc_Version_id);

Alter table GWL.f_JDBCCnxPl_day
add constraint serv_6
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JDBCCnxPl_day
add constraint vers_6
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_JDBCCnxPl_day
add constraint host_6
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JDBCCnxPl_day
add constraint cpmt_2
foreign key (metric_id)
references GWL.d_JDBCCnxPl_metric (metric_id);        

-----------------------------
-- Weekly Fact Table: JDBCCnxPl 
-----------------------------

create table GWL.f_JDBCCnxPl_week (
 JDBCCnxPl_id                 integer        not null,
 Jc_Version_id		   integer	not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           integer,
        primary key (JDBCCnxPl_id,
       Jc_Version_id,	
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_cxpl_wk1 on GWL.f_JDBCCnxPl_week (JDBCCnxPl_id);
create index gwl.f_cxpl_wk2 on GWL.f_JDBCCnxPl_week (Jc_Version_id);
create index gwl.f_cxpl_wk3 on GWL.f_JDBCCnxPl_week (Server_id);
create index gwl.f_cxpl_wk4 on GWL.f_JDBCCnxPl_week (Sv_Version_id);
create index gwl.f_cxpl_wk5 on GWL.f_JDBCCnxPl_week (host_id);
create index gwl.f_cxpl_wk6 on GWL.f_JDBCCnxPl_week (metric_id);
create index gwl.f_cxpl_wk7 on GWL.f_JDBCCnxPl_week (meas_date);

Alter table GWL.f_JDBCCnxPl_week
add constraint cxpl_3
foreign key (JDBCCnxPl_id)
references GWL.d_JDBCCnxPl (JDBCCnxPl_id);

Alter table GWL.f_JDBCCnxPl_week
add constraint jcvs_3
foreign key (Jc_Version_id)
references GWL.d_Jc_Version (Jc_Version_id);

Alter table GWL.f_JDBCCnxPl_week
add constraint serv_7
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JDBCCnxPl_week
add constraint vers_7
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_JDBCCnxPl_week
add constraint host_7
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JDBCCnxPl_week
add constraint cpmt_3
foreign key (metric_id)
references GWL.d_JDBCCnxPl_metric (metric_id); 

-----------------------------
-- Monthly Fact Table: JDBCCnxPl 
-----------------------------

create table GWL.f_JDBCCnxPl_month (
 JDBCCnxPl_id                 integer        not null,
 Jc_Version_id         	   integer	  not null, 
 Server_id		   integer	not null,
 Sv_Version_id         	   integer	  not null, 
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           integer,
        primary key (JDBCCnxPl_id,
       Jc_Version_id,	
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_cxpl_mo1 on GWL.f_JDBCCnxPl_month (JDBCCnxPl_id);
create index gwl.f_cxpl_mo2 on GWL.f_JDBCCnxPl_month (Jc_Version_id);
create index gwl.f_cxpl_mo3 on GWL.f_JDBCCnxPl_month (Server_id);
create index gwl.f_cxpl_mo4 on GWL.f_JDBCCnxPl_month (Sv_Version_id);
create index gwl.f_cxpl_mo5 on GWL.f_JDBCCnxPl_month (host_id);
create index gwl.f_cxpl_mo6 on GWL.f_JDBCCnxPl_month (metric_id);
create index gwl.f_cxpl_mo7 on GWL.f_JDBCCnxPl_month (meas_date);

Alter table GWL.f_JDBCCnxPl_month
add constraint cxpl_4
foreign key (JDBCCnxPl_id)
references GWL.d_JDBCCnxPl (JDBCCnxPl_id);

Alter table GWL.f_JDBCCnxPl_month
add constraint jcvs_4
foreign key (Jc_Version_id)
references GWL.d_Jc_Version (Jc_Version_id);

Alter table GWL.f_JDBCCnxPl_month
add constraint serv_8
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JDBCCnxPl_month
add constraint vers_8
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_JDBCCnxPl_month
add constraint host_8
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JDBCCnxPl_month
add constraint cpmt_4
foreign key (metric_id)
references GWL.d_JDBCCnxPl_metric (metric_id);       

--------------------
--- WebLogic JMSCnx 
--------------------

---------------------------------
-- Dimension Table: JMSCnx Metric 
---------------------------------

create table GWL.d_JMSCnx_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254) not null,
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- Translation table

create table GWL.t_JMSCnx_metric (
  orig_metric_id 		INTEGER not null,
  metric_id			INTEGER,
  cdw_id 			INTEGER not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			VARCHAR(254) not null,
  met_units 			VARCHAR(254) not null,
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--SEQUENCE      

create sequence GWL.jcmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.jcmt_i1
no cascade before insert on GWL.d_JMSCnx_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for GWL.jcmt_id_seq;

-----------------------------
-- Dimension Table: JMSCnx 
-----------------------------

create table GWL.d_JMSCnx (
 JMSCnx_id     	           integer        not null,
 JMSCnxName                varchar(254)   not null,
 ClientId		   varchar(254)   not null,
      primary key (JMSCnx_id));

-- Translation table

create table GWL.t_JMSCnx (
 orig_JMSCnx_id            integer        not null,
 JMSCnx_id		   integer,
 cdw_id			   integer        not null,
 JMSCnxName                varchar(254)   not null,
 ClientId		   varchar(254)   not null,
      primary key (orig_JMSCnx_id,cdw_id)
      );

--SEQUENCE      

create sequence GWL.jmsc_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.jmsc_i1
no cascade before insert on GWL.d_JMSCnx  
referencing new as n for each row mode db2sql
set n.JMSCnx_id = nextval for GWL.jmsc_id_seq;
      
     
-----------------------------
-- Hourly Fact Table: JMSCnx 
-----------------------------

create table GWL.f_JMSCnx_hour (
 JMSCnx_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id         	   integer        not null, 
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           integer,
       primary key (JMSCnx_id,
       Server_id,
       Sv_Version_id, 
       host_id, metric_id, 
       meas_hour)
       );

create index gwl.f_jmsc_hr1 on GWL.f_JMSCnx_hour (JMSCnx_id);
create index gwl.f_jmsc_hr2 on GWL.f_JMSCnx_hour (Server_id);
create index gwl.f_jmsc_hr3 on GWL.f_JMSCnx_hour (Sv_Version_id);
create index gwl.f_jmsc_hr4 on GWL.f_JMSCnx_hour (host_id);
create index gwl.f_jmsc_hr5 on GWL.f_JMSCnx_hour (metric_id);
create index gwl.f_jmsc_hr6 on GWL.f_JMSCnx_hour (meas_hour);

Alter table GWL.f_JMSCnx_hour
add constraint jmsc_1
foreign key (JMSCnx_id)
references GWL.d_JMSCnx (JMSCnx_id);

Alter table GWL.f_JMSCnx_hour
add constraint serv_9
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JMSCnx_hour
add constraint vers_9 
foreign key (Sv_Version_id)
references GWL.d_sv_Version (sv_version_id);

Alter table GWL.f_JMSCnx_hour
add constraint host_9
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JMSCnx_hour
add constraint jcmt_1
foreign key (metric_id)
references GWL.d_JMSCnx_metric (metric_id);       

--Staging hour fact table
create table GWL.stg_JMSCnx_hr (
 msmt_id		   integer	  not null,
 orig_JMSCnx_id            integer        not null,
 orig_Server_id		   integer	not null,
 Sv_Version	 	   varchar(254)   not null, 
 orig_host_id              integer        not null,
 orig_metric_id            integer        not null,
 cdw_id			   integer        not null	,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           integer,
       primary key (msmt_id,cdw_id)
       );

-----------------------------
-- Daily Fact Table: JMSCnx 
-----------------------------

create table GWL.f_JMSCnx_day (
 JMSCnx_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	  not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (JMSCnx_id,
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_jmsc_day1 on GWL.f_JMSCnx_day (JMSCnx_id);
create index gwl.f_jmsc_day2 on GWL.f_JMSCnx_day (Server_id);
create index gwl.f_jmsc_day3 on GWL.f_JMSCnx_day (Sv_Version_id);
create index gwl.f_jmsc_day4 on GWL.f_JMSCnx_day (host_id);
create index gwl.f_jmsc_day5 on GWL.f_JMSCnx_day (metric_id);
create index gwl.f_jmsc_day6 on GWL.f_JMSCnx_day (meas_date);

Alter table GWL.f_JMSCnx_day
add constraint jmsc_2
foreign key (JMSCnx_id)
references GWL.d_JMSCnx (JMSCnx_id);

Alter table GWL.f_JMSCnx_day
add constraint serv_10
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JMSCnx_day
add constraint vers_10 
foreign key (Sv_Version_id)
references GWL.d_sv_Version (sv_version_id);

Alter table GWL.f_JMSCnx_day
add constraint host_10
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JMSCnx_day
add constraint jcmt_2
foreign key (metric_id)
references GWL.d_JMSCnx_metric (metric_id);        


-----------------------------
-- Weekly Fact Table: JMSCnx 
-----------------------------

create table GWL.f_JMSCnx_week (
 JMSCnx_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	  not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (JMSCnx_id,
       Server_id,
       Sv_Version_id, 
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_jmsc_wk1 on GWL.f_JMSCnx_week (JMSCnx_id);
create index gwl.f_jmsc_wk2 on GWL.f_JMSCnx_week (Server_id);
create index gwl.f_jmsc_wk3 on GWL.f_JMSCnx_week (Sv_Version_id);
create index gwl.f_jmsc_wk4 on GWL.f_JMSCnx_week (host_id);
create index gwl.f_jmsc_wk5 on GWL.f_JMSCnx_week (metric_id);
create index gwl.f_jmsc_wk6 on GWL.f_JMSCnx_week (meas_date);

Alter table GWL.f_JMSCnx_week
add constraint jmsc_3
foreign key (JMSCnx_id)
references GWL.d_JMSCnx (JMSCnx_id);

Alter table GWL.f_JMSCnx_week
add constraint serv_11
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JMSCnx_week
add constraint vers_11 
foreign key (Sv_Version_id)
references GWL.d_sv_Version (sv_version_id);

Alter table GWL.f_JMSCnx_week
add constraint host_11
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JMSCnx_week
add constraint jcmt_3
foreign key (metric_id)
references GWL.d_JMSCnx_metric (metric_id); 

-----------------------------
-- Monthly Fact Table: JMSCnx 
-----------------------------

create table GWL.f_JMSCnx_month (
 JMSCnx_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	  not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (JMSCnx_id,
       Server_id,
       Sv_version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_jmsc_mo1 on GWL.f_JMSCnx_month (JMSCnx_id);
create index gwl.f_jmsc_mo3 on GWL.f_JMSCnx_month (Server_id);
create index gwl.f_jmsc_mo2 on GWL.f_JMSCnx_month (Sv_Version_id);
create index gwl.f_jmsc_mo4 on GWL.f_JMSCnx_month (host_id);
create index gwl.f_jmsc_mo5 on GWL.f_JMSCnx_month (metric_id);
create index gwl.f_jmsc_mo6 on GWL.f_JMSCnx_month (meas_date);

Alter table GWL.f_JMSCnx_month
add constraint jmsc_4
foreign key (JMSCnx_id)
references GWL.d_JMSCnx (JMSCnx_id);

Alter table GWL.f_JMSCnx_month
add constraint serv_12
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JMSCnx_month
add constraint vers_12
foreign key (Sv_Version_id)
references GWL.d_sv_Version (sv_version_id);

Alter table GWL.f_JMSCnx_month
add constraint host_12
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JMSCnx_month
add constraint jcmt_4
foreign key (metric_id)
references GWL.d_JMSCnx_metric (metric_id);       

--------------------
--- WebLogic JMSSrv 
--------------------

---------------------------------
-- Dimension Table: JMSSrv Metric 
---------------------------------

create table GWL.d_JMSSrv_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254) not null,
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- Translation table

create table GWL.t_JMSSrv_metric (
  orig_metric_id 		INTEGER not null,
  metric_id			INTEGER,
  cdw_id 			INTEGER not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			VARCHAR(254) not null,
  met_units 			VARCHAR(254) not null,
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--SEQUENCE      

create sequence GWL.jsmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.jsmt_i1
no cascade before insert on GWL.d_JMSSrv_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for GWL.jsmt_id_seq;

-----------------------------
-- Dimension Table: JMSSrv 
-----------------------------

create table GWL.d_JMSSrv (
 JMSSrv_id     	           integer        not null,
 JMSSrvName                varchar(254)   not null,
      primary key (JMSSrv_id));

-- Translation table

create table GWL.t_JMSSrv (
 orig_JMSSrv_id            integer        not null,
 JMSSrv_id		   integer,
 cdw_id			   integer        not null,
 JMSSrvName                varchar(254)   not null,
      primary key (orig_JMSSrv_id,cdw_id)
      );

--SEQUENCE      

create sequence GWL.jmss_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.jmss_i1
no cascade before insert on GWL.d_JMSSrv  
referencing new as n for each row mode db2sql
set n.JMSSrv_id = nextval for GWL.jmss_id_seq;
      
-----------------------------
-- Hourly Fact Table: JMSSrv 
-----------------------------

create table GWL.f_JMSSrv_hour (
 JMSSrv_id                 integer       not null,
 Server_id		   integer	  not null,
 Sv_Version_id		   integer 	  not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (JMSSrv_id,
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_hour)
       );

create index gwl.f_jmss_hr1 on GWL.f_JMSSrv_hour (JMSSrv_id);
create index gwl.f_jmss_hr2 on GWL.f_JMSSrv_hour (Server_id);
create index gwl.f_jmss_hr3 on GWL.f_JMSSrv_hour (Sv_Version_id);
create index gwl.f_jmss_hr4 on GWL.f_JMSSrv_hour (host_id);
create index gwl.f_jmss_hr5 on GWL.f_JMSSrv_hour (metric_id);
create index gwl.f_jmss_hr6 on GWL.f_JMSSrv_hour (meas_hour);

Alter table GWL.f_JMSSrv_hour
add constraint jmss_1
foreign key (JMSSrv_id)
references GWL.d_JMSSrv (JMSSrv_id);

Alter table GWL.f_JMSSrv_hour
add constraint serv_13
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JMSSrv_hour
add constraint vers_13
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_JMSSrv_hour
add constraint host_13
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JMSSrv_hour
add constraint jsmt_1
foreign key (metric_id)
references GWL.d_JMSSrv_metric (metric_id);       

--Staging hour fact table
create table GWL.stg_JMSSrv_hr (
 msmt_id		   integer	  not null,
 orig_JMSSrv_id            integer        not null,
 orig_Server_id		   integer	not null,
 Sv_Version		   varchar(254) not null,
 orig_host_id              integer        not null,
 orig_metric_id            integer        not null,
 cdw_id			   integer        not null	,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

-----------------------------
-- Daily Fact Table: JMSSrv 
-----------------------------

create table GWL.f_JMSSrv_day (
 JMSSrv_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (JMSSrv_id,
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_jmss_day1 on GWL.f_JMSSrv_day (JMSSrv_id);
create index gwl.f_jmss_day2 on GWL.f_JMSSrv_day (Server_id);
create index gwl.f_jmss_day3 on GWL.f_JMSSrv_day (Sv_Version_id);
create index gwl.f_jmss_day4 on GWL.f_JMSSrv_day (host_id);
create index gwl.f_jmss_day5 on GWL.f_JMSSrv_day (metric_id);
create index gwl.f_jmss_day6 on GWL.f_JMSSrv_day (meas_date);

Alter table GWL.f_JMSSrv_day
add constraint jmss_2
foreign key (JMSSrv_id)
references GWL.d_JMSSrv (JMSSrv_id);

Alter table GWL.f_JMSSrv_day
add constraint serv_14
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JMSSrv_day
add constraint vers_14
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_JMSSrv_day
add constraint host_14
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JMSSrv_day
add constraint jsmt_2
foreign key (metric_id)
references GWL.d_JMSSrv_metric (metric_id);        


-----------------------------
-- Weekly Fact Table: JMSSrv 
-----------------------------

create table GWL.f_JMSSrv_week (
 JMSSrv_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (JMSSrv_id,
	Server_id,
	Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_jmss_wk1 on GWL.f_JMSSrv_week (JMSSrv_id);
create index gwl.f_jmss_wk2 on GWL.f_JMSSrv_week (Server_id);
create index gwl.f_jmss_wk3 on GWL.f_JMSSrv_week (Sv_Version_id);
create index gwl.f_jmss_wk4 on GWL.f_JMSSrv_week (host_id);
create index gwl.f_jmss_wk5 on GWL.f_JMSSrv_week (metric_id);
create index gwl.f_jmss_wk6 on GWL.f_JMSSrv_week (meas_date);

Alter table GWL.f_JMSSrv_week
add constraint jmss_3
foreign key (JMSSrv_id)
references GWL.d_JMSSrv (JMSSrv_id);

Alter table GWL.f_JMSSrv_week
add constraint serv_15
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JMSSrv_week
add constraint vers_15
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_JMSSrv_week
add constraint host_15
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JMSSrv_week
add constraint jsmt_3
foreign key (metric_id)
references GWL.d_JMSSrv_metric (metric_id); 

-----------------------------
-- Monthly Fact Table: JMSSrv 
-----------------------------

create table GWL.f_JMSSrv_month (
 JMSSrv_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (JMSSrv_id,
	Server_id,
	Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_jmss_mo1 on GWL.f_JMSSrv_month (JMSSrv_id);
create index gwl.f_jmss_mo2 on GWL.f_JMSSrv_month (Server_id);
create index gwl.f_jmss_mo3 on GWL.f_JMSSrv_month (Sv_Version_id);
create index gwl.f_jmss_mo4 on GWL.f_JMSSrv_month (host_id);
create index gwl.f_jmss_mo5 on GWL.f_JMSSrv_month (metric_id);
create index gwl.f_jmss_mo6 on GWL.f_JMSSrv_month (meas_date);

Alter table GWL.f_JMSSrv_month
add constraint jmss_4
foreign key (JMSSrv_id)
references GWL.d_JMSSrv (JMSSrv_id);

Alter table GWL.f_JMSSrv_month
add constraint serv_16
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JMSSrv_month
add constraint vers_16
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_JMSSrv_month
add constraint host_16
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JMSSrv_month
add constraint jsmt_4
foreign key (metric_id)
references GWL.d_JMSSrv_metric (metric_id);       

--------------------
--- WebLogic Appl 
--------------------

---------------------------------
-- Dimension Table: Appl Metric 
---------------------------------

create table GWL.d_Appl_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254) not null,
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- Translation table

create table GWL.t_Appl_metric (
  orig_metric_id 		INTEGER not null,
  metric_id			INTEGER,
  cdw_id 			INTEGER not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			VARCHAR(254) not null,
  met_units 			VARCHAR(254) not null,
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--SEQUENCE      

create sequence GWL.apmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.apmt_i1
no cascade before insert on GWL.d_Appl_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for GWL.apmt_id_seq;

-----------------------------
-- Dimension Table: Appl 
-----------------------------

create table GWL.d_Appl (
 Appl_id     	           integer        not null,
 ApplName                varchar(254)   not null,
      primary key (Appl_id));

-- Translation table

create table GWL.t_Appl (
 orig_Appl_id            integer        not null,
 Appl_id		 integer,
 cdw_id			   integer        not null,
 ApplName                varchar(254)   not null,
      primary key (orig_Appl_id,cdw_id)
      );

--SEQUENCE      

create sequence GWL.appl_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.appl_i1
no cascade before insert on GWL.d_Appl  
referencing new as n for each row mode db2sql
set n.Appl_id = nextval for GWL.appl_id_seq;
      
-----------------------------
-- Hourly Fact Table: Appl 
-----------------------------

create table GWL.f_Appl_hour (
 Appl_id                 integer       not null,
 Server_id		   integer	  not null,
 Sv_Version_id		   integer 	  not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (Appl_id,
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_hour)
       );

create index gwl.f_appl_hr1 on GWL.f_Appl_hour (Appl_id);
create index gwl.f_appl_hr2 on GWL.f_Appl_hour (Server_id);
create index gwl.f_appl_hr3 on GWL.f_Appl_hour (Sv_Version_id);
create index gwl.f_appl_hr4 on GWL.f_Appl_hour (host_id);
create index gwl.f_appl_hr5 on GWL.f_Appl_hour (metric_id);
create index gwl.f_appl_hr6 on GWL.f_Appl_hour (meas_hour);

Alter table GWL.f_Appl_hour
add constraint appl_1
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_Appl_hour
add constraint serv_17
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Appl_hour
add constraint vers_17
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_Appl_hour
add constraint host_17
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Appl_hour
add constraint apmt_1
foreign key (metric_id)
references GWL.d_Appl_metric (metric_id);       

--Staging hour fact table
create table GWL.stg_Appl_hr (
 msmt_id		   integer	  not null,
 orig_Appl_id            integer        not null,
 orig_Server_id		   integer	not null,
 Sv_Version		   varchar(254) not null,
 orig_host_id              integer        not null,
 orig_metric_id            integer        not null,
 cdw_id			   integer        not null	,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

-----------------------------
-- Daily Fact Table: Appl 
-----------------------------

create table GWL.f_Appl_day (
 Appl_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (Appl_id,
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_appl_day1 on GWL.f_Appl_day (Appl_id);
create index gwl.f_appl_day2 on GWL.f_Appl_day (Server_id);
create index gwl.f_appl_day3 on GWL.f_Appl_day (Sv_Version_id);
create index gwl.f_appl_day4 on GWL.f_Appl_day (host_id);
create index gwl.f_appl_day5 on GWL.f_Appl_day (metric_id);
create index gwl.f_appl_day6 on GWL.f_Appl_day (meas_date);

Alter table GWL.f_Appl_day
add constraint appl_2
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_Appl_day
add constraint serv_18
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Appl_day
add constraint vers_18
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_Appl_day
add constraint host_18
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Appl_day
add constraint apmt_2
foreign key (metric_id)
references GWL.d_Appl_metric (metric_id);        


-----------------------------
-- Weekly Fact Table: Appl 
-----------------------------

create table GWL.f_Appl_week (
 Appl_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (Appl_id,
	Server_id,
	Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_appl_wk1 on GWL.f_Appl_week (Appl_id);
create index gwl.f_appl_wk2 on GWL.f_Appl_week (Server_id);
create index gwl.f_appl_wk3 on GWL.f_Appl_week (Sv_Version_id);
create index gwl.f_appl_wk4 on GWL.f_Appl_week (host_id);
create index gwl.f_appl_wk5 on GWL.f_Appl_week (metric_id);
create index gwl.f_appl_wk6 on GWL.f_Appl_week (meas_date);

Alter table GWL.f_Appl_week
add constraint appl_3
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_Appl_week
add constraint serv_19
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Appl_week
add constraint vers_19
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_Appl_week
add constraint host_19
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Appl_week
add constraint apmt_3
foreign key (metric_id)
references GWL.d_Appl_metric (metric_id); 

-----------------------------
-- Monthly Fact Table: Appl 
-----------------------------

create table GWL.f_Appl_month (
 Appl_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (Appl_id,
	Server_id,
	Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_appl_mo1 on GWL.f_Appl_month (Appl_id);
create index gwl.f_appl_mo2 on GWL.f_Appl_month (Server_id);
create index gwl.f_appl_mo3 on GWL.f_Appl_month (Sv_Version_id);
create index gwl.f_appl_mo4 on GWL.f_Appl_month (host_id);
create index gwl.f_appl_mo5 on GWL.f_Appl_month (metric_id);
create index gwl.f_appl_mo6 on GWL.f_Appl_month (meas_date);

Alter table GWL.f_Appl_month
add constraint appl_4
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_Appl_month
add constraint serv_20
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Appl_month
add constraint vers_20
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_Appl_month
add constraint host_20
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Appl_month
add constraint apmt_4
foreign key (metric_id)
references GWL.d_Appl_metric (metric_id);       

--------------------
--- WebLogic Ex_Qu 
--------------------

---------------------------------
-- Dimension Table: Ex_Qu Metric 
---------------------------------

create table GWL.d_Ex_Qu_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254) not null,
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- Translation table

create table GWL.t_Ex_Qu_metric (
  orig_metric_id 		INTEGER not null,
  metric_id			INTEGER,
  cdw_id 			INTEGER not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			VARCHAR(254) not null,
  met_units 			VARCHAR(254) not null,
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--SEQUENCE      

create sequence GWL.eqmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.eqmt_i1
no cascade before insert on GWL.d_Ex_Qu_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for GWL.eqmt_id_seq;

-----------------------------
-- Dimension Table: Ex_Qu 
-----------------------------

create table GWL.d_Ex_Qu (
 Ex_Qu_id     	           integer        not null,
 ExQuName                varchar(254)   not null,
      primary key (Ex_Qu_id));

-- Translation table

create table GWL.t_Ex_Qu (
 orig_Ex_Qu_id            integer        not null,
 Ex_Qu_id		  integer,
 cdw_id			   integer        not null,
 ExQuName                varchar(254)   not null,
      primary key (orig_Ex_Qu_id,cdw_id)
      );

--SEQUENCE      

create sequence GWL.exqu_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.exqu_i1
no cascade before insert on GWL.d_Ex_Qu  
referencing new as n for each row mode db2sql
set n.Ex_Qu_id = nextval for GWL.exqu_id_seq;
      
-----------------------------
-- Hourly Fact Table: Ex_Qu 
-----------------------------

create table GWL.f_Ex_Qu_hour (
 Ex_Qu_id                 integer       not null,
 Server_id		   integer	  not null,
 Sv_Version_id		   integer 	  not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (Ex_Qu_id,
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_hour)
       );

create index gwl.f_exqu_hr1 on GWL.f_Ex_Qu_hour (Ex_Qu_id);
create index gwl.f_exqu_hr2 on GWL.f_Ex_Qu_hour (Server_id);
create index gwl.f_exqu_hr3 on GWL.f_Ex_Qu_hour (Sv_Version_id);
create index gwl.f_exqu_hr4 on GWL.f_Ex_Qu_hour (host_id);
create index gwl.f_exqu_hr5 on GWL.f_Ex_Qu_hour (metric_id);
create index gwl.f_exqu_hr6 on GWL.f_Ex_Qu_hour (meas_hour);

Alter table GWL.f_Ex_Qu_hour
add constraint exqu_1
foreign key (Ex_Qu_id)
references GWL.d_Ex_Qu (Ex_Qu_id);

Alter table GWL.f_Ex_Qu_hour
add constraint serv_21
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Ex_Qu_hour
add constraint vers_21
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_Ex_Qu_hour
add constraint host_21
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Ex_Qu_hour
add constraint eqmt_1
foreign key (metric_id)
references GWL.d_Ex_Qu_metric (metric_id);       

--Staging hour fact table
create table GWL.stg_Ex_Qu_hr (
 msmt_id		   integer	  not null,
 orig_Ex_Qu_id            integer        not null,
 orig_Server_id		   integer	not null,
 Sv_Version		   varchar(254) not null,
 orig_host_id              integer        not null,
 orig_metric_id            integer        not null,
 cdw_id			   integer        not null	,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

-----------------------------
-- Daily Fact Table: Ex_Qu 
-----------------------------

create table GWL.f_Ex_Qu_day (
 Ex_Qu_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (Ex_Qu_id,
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_exqu_day1 on GWL.f_Ex_Qu_day (Ex_Qu_id);
create index gwl.f_exqu_day2 on GWL.f_Ex_Qu_day (Server_id);
create index gwl.f_exqu_day3 on GWL.f_Ex_Qu_day (Sv_Version_id);
create index gwl.f_exqu_day4 on GWL.f_Ex_Qu_day (host_id);
create index gwl.f_exqu_day5 on GWL.f_Ex_Qu_day (metric_id);
create index gwl.f_exqu_day6 on GWL.f_Ex_Qu_day (meas_date);

Alter table GWL.f_Ex_Qu_day
add constraint exqu_2
foreign key (Ex_Qu_id)
references GWL.d_Ex_Qu (Ex_Qu_id);

Alter table GWL.f_Ex_Qu_day
add constraint serv_22
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Ex_Qu_day
add constraint vers_22
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_Ex_Qu_day
add constraint host_22
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Ex_Qu_day
add constraint eqmt_2
foreign key (metric_id)
references GWL.d_Ex_Qu_metric (metric_id);        


-----------------------------
-- Weekly Fact Table: Ex_Qu 
-----------------------------

create table GWL.f_Ex_Qu_week (
 Ex_Qu_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (Ex_Qu_id,
	Server_id,
	Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_exqu_wk1 on GWL.f_Ex_Qu_week (Ex_Qu_id);
create index gwl.f_exqu_wk2 on GWL.f_Ex_Qu_week (Server_id);
create index gwl.f_exqu_wk3 on GWL.f_Ex_Qu_week (Sv_Version_id);
create index gwl.f_exqu_wk4 on GWL.f_Ex_Qu_week (host_id);
create index gwl.f_exqu_wk5 on GWL.f_Ex_Qu_week (metric_id);
create index gwl.f_exqu_wk6 on GWL.f_Ex_Qu_week (meas_date);

Alter table GWL.f_Ex_Qu_week
add constraint exqu_3
foreign key (Ex_Qu_id)
references GWL.d_Ex_Qu (Ex_Qu_id);

Alter table GWL.f_Ex_Qu_week
add constraint serv_23
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Ex_Qu_week
add constraint vers_23
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_Ex_Qu_week
add constraint host_23
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Ex_Qu_week
add constraint eqmt_3
foreign key (metric_id)
references GWL.d_Ex_Qu_metric (metric_id); 

-----------------------------
-- Monthly Fact Table: Ex_Qu 
-----------------------------

create table GWL.f_Ex_Qu_month (
 Ex_Qu_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (Ex_Qu_id,
	Server_id,
	Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_exqu_mo1 on GWL.f_Ex_Qu_month (Ex_Qu_id);
create index gwl.f_exqu_mo2 on GWL.f_Ex_Qu_month (Server_id);
create index gwl.f_exqu_mo3 on GWL.f_Ex_Qu_month (Sv_Version_id);
create index gwl.f_exqu_mo4 on GWL.f_Ex_Qu_month (host_id);
create index gwl.f_exqu_mo5 on GWL.f_Ex_Qu_month (metric_id);
create index gwl.f_exqu_mo6 on GWL.f_Ex_Qu_month (meas_date);

Alter table GWL.f_Ex_Qu_month
add constraint exqu_4
foreign key (Ex_Qu_id)
references GWL.d_Ex_Qu (Ex_Qu_id);

Alter table GWL.f_Ex_Qu_month
add constraint serv_24
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Ex_Qu_month
add constraint vers_24
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_Ex_Qu_month
add constraint host_24
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Ex_Qu_month
add constraint eqmt_4
foreign key (metric_id)
references GWL.d_Ex_Qu_metric (metric_id);       

--------------------
--- WebLogic Serv_Sec 
--------------------

---------------------------------
-- Dimension Table: Serv_Sec Metric 
---------------------------------

create table GWL.d_Serv_Sec_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254) not null,
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- Translation table

create table GWL.t_Serv_Sec_metric (
  orig_metric_id 		INTEGER not null,
  metric_id			INTEGER,
  cdw_id 			INTEGER not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			VARCHAR(254) not null,
  met_units 			VARCHAR(254) not null,
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--SEQUENCE      

create sequence GWL.ssmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.ssmt_i1
no cascade before insert on GWL.d_Serv_Sec_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for GWL.ssmt_id_seq;

-----------------------------
-- Dimension Table: Serv_Sec 
-----------------------------

create table GWL.d_Serv_Sec (
 Serv_Sec_id     	           integer        not null,
 SevSecName                varchar(254)   not null,
      primary key (Serv_Sec_id));

-- Translation table

create table GWL.t_Serv_Sec (
 orig_Serv_Sec_id            integer        not null,
 Serv_Sec_id		   integer,
 cdw_id			   integer        not null,
 SevSecName                varchar(254)   not null,
      primary key (orig_Serv_Sec_id,cdw_id)
      );

--SEQUENCE      

create sequence GWL.svsc_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.svsc_i1
no cascade before insert on GWL.d_Serv_Sec  
referencing new as n for each row mode db2sql
set n.Serv_Sec_id = nextval for GWL.svsc_id_seq;
      
-----------------------------
-- Hourly Fact Table: Serv_Sec 
-----------------------------

create table GWL.f_Serv_Sec_hour (
 Serv_Sec_id                 integer       not null,
 Server_id		   integer	  not null,
 Sv_Version_id		   integer 	  not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (Serv_Sec_id,
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_hour)
       );

create index gwl.f_svsc_hr1 on GWL.f_Serv_Sec_hour (Serv_Sec_id);
create index gwl.f_svsc_hr2 on GWL.f_Serv_Sec_hour (Server_id);
create index gwl.f_svsc_hr3 on GWL.f_Serv_Sec_hour (Sv_Version_id);
create index gwl.f_svsc_hr4 on GWL.f_Serv_Sec_hour (host_id);
create index gwl.f_svsc_hr5 on GWL.f_Serv_Sec_hour (metric_id);
create index gwl.f_svsc_hr6 on GWL.f_Serv_Sec_hour (meas_hour);

Alter table GWL.f_Serv_Sec_hour
add constraint svsc_1
foreign key (Serv_Sec_id)
references GWL.d_Serv_Sec (Serv_Sec_id);

Alter table GWL.f_Serv_Sec_hour
add constraint serv_25
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Serv_Sec_hour
add constraint vers_25
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_Serv_Sec_hour
add constraint host_25
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Serv_Sec_hour
add constraint ssmt_1
foreign key (metric_id)
references GWL.d_Serv_Sec_metric (metric_id);       

--Staging hour fact table
create table GWL.stg_Serv_Sec_hr (
 msmt_id		   integer	  not null,
 orig_Serv_Sec_id            integer        not null,
 orig_Server_id		   integer	not null,
 Sv_Version		   varchar(254) not null,
 orig_host_id              integer        not null,
 orig_metric_id            integer        not null,
 cdw_id			   integer        not null	,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

-----------------------------
-- Daily Fact Table: Serv_Sec 
-----------------------------

create table GWL.f_Serv_Sec_day (
 Serv_Sec_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (Serv_Sec_id,
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_svsc_day1 on GWL.f_Serv_Sec_day (Serv_Sec_id);
create index gwl.f_svsc_day2 on GWL.f_Serv_Sec_day (Server_id);
create index gwl.f_svsc_day3 on GWL.f_Serv_Sec_day (Sv_Version_id);
create index gwl.f_svsc_day4 on GWL.f_Serv_Sec_day (host_id);
create index gwl.f_svsc_day5 on GWL.f_Serv_Sec_day (metric_id);
create index gwl.f_svsc_day6 on GWL.f_Serv_Sec_day (meas_date);

Alter table GWL.f_Serv_Sec_day
add constraint svsc_2
foreign key (Serv_Sec_id)
references GWL.d_Serv_Sec (Serv_Sec_id);

Alter table GWL.f_Serv_Sec_day
add constraint serv_26
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Serv_Sec_day
add constraint vers_26
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_Serv_Sec_day
add constraint host_26
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Serv_Sec_day
add constraint ssmt_2
foreign key (metric_id)
references GWL.d_Serv_Sec_metric (metric_id);        


-----------------------------
-- Weekly Fact Table: Serv_Sec 
-----------------------------

create table GWL.f_Serv_Sec_week (
 Serv_Sec_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (Serv_Sec_id,
	Server_id,
	Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_svsc_wk1 on GWL.f_Serv_Sec_week (Serv_Sec_id);
create index gwl.f_svsc_wk2 on GWL.f_Serv_Sec_week (Server_id);
create index gwl.f_svsc_wk3 on GWL.f_Serv_Sec_week (Sv_Version_id);
create index gwl.f_svsc_wk4 on GWL.f_Serv_Sec_week (host_id);
create index gwl.f_svsc_wk5 on GWL.f_Serv_Sec_week (metric_id);
create index gwl.f_svsc_wk6 on GWL.f_Serv_Sec_week (meas_date);

Alter table GWL.f_Serv_Sec_week
add constraint svsc_3
foreign key (Serv_Sec_id)
references GWL.d_Serv_Sec (Serv_Sec_id);

Alter table GWL.f_Serv_Sec_week
add constraint serv_27
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Serv_Sec_week
add constraint vers_27
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_Serv_Sec_week
add constraint host_27
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Serv_Sec_week
add constraint ssmt_3
foreign key (metric_id)
references GWL.d_Serv_Sec_metric (metric_id); 

-----------------------------
-- Monthly Fact Table: Serv_Sec 
-----------------------------

create table GWL.f_Serv_Sec_month (
 Serv_Sec_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (Serv_Sec_id,
	Server_id,
	Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_svsc_mo1 on GWL.f_Serv_Sec_month (Serv_Sec_id);
create index gwl.f_svsc_mo2 on GWL.f_Serv_Sec_month (Server_id);
create index gwl.f_svsc_mo3 on GWL.f_Serv_Sec_month (Sv_Version_id);
create index gwl.f_svsc_mo4 on GWL.f_Serv_Sec_month (host_id);
create index gwl.f_svsc_mo5 on GWL.f_Serv_Sec_month (metric_id);
create index gwl.f_svsc_mo6 on GWL.f_Serv_Sec_month (meas_date);

Alter table GWL.f_Serv_Sec_month
add constraint svsc_4
foreign key (Serv_Sec_id)
references GWL.d_Serv_Sec (Serv_Sec_id);

Alter table GWL.f_Serv_Sec_month
add constraint serv_28
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Serv_Sec_month
add constraint vers_28
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_Serv_Sec_month
add constraint host_28
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Serv_Sec_month
add constraint ssmt_4
foreign key (metric_id)
references GWL.d_Serv_Sec_metric (metric_id);       

--------------------
--- WebLogic Log_Bdct 
--------------------

---------------------------------
-- Dimension Table: Log_Bdct Metric 
---------------------------------

create table GWL.d_Log_Bdct_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254) not null,
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- Translation table

create table GWL.t_Log_Bdct_metric (
  orig_metric_id 		INTEGER not null,
  metric_id			INTEGER,
  cdw_id 			INTEGER not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			VARCHAR(254) not null,
  met_units 			VARCHAR(254) not null,
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--SEQUENCE      

create sequence GWL.lgmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.lgmt_i1
no cascade before insert on GWL.d_Log_Bdct_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for GWL.lgmt_id_seq;

-----------------------------
-- Dimension Table: Log_Bdct 
-----------------------------

create table GWL.d_Log_Bdct (
 Log_Bdct_id     	           integer        not null,
 LogBdctName                varchar(254)   not null,
      primary key (Log_Bdct_id));

-- Translation table

create table GWL.t_Log_Bdct (
 orig_Log_Bdct_id            integer        not null,
 Log_Bdct_id		   integer,
 cdw_id			   integer        not null,
 LogBdctName                varchar(254)   not null,
      primary key (orig_Log_Bdct_id,cdw_id)
      );

--SEQUENCE      

create sequence GWL.lgbd_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.lgbd_i1
no cascade before insert on GWL.d_Log_Bdct  
referencing new as n for each row mode db2sql
set n.Log_Bdct_id = nextval for GWL.lgbd_id_seq;
      
-----------------------------
-- Hourly Fact Table: Log_Bdct 
-----------------------------

create table GWL.f_Log_Bdct_hour (
 Log_Bdct_id                 integer       not null,
 Server_id		   integer	  not null,
 Sv_Version_id		   integer 	  not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (Log_Bdct_id,
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_hour)
       );

create index gwl.f_lgbd_hr1 on GWL.f_Log_Bdct_hour (Log_Bdct_id);
create index gwl.f_lgbd_hr2 on GWL.f_Log_Bdct_hour (Server_id);
create index gwl.f_lgbd_hr3 on GWL.f_Log_Bdct_hour (Sv_Version_id);
create index gwl.f_lgbd_hr4 on GWL.f_Log_Bdct_hour (host_id);
create index gwl.f_lgbd_hr5 on GWL.f_Log_Bdct_hour (metric_id);
create index gwl.f_lgbd_hr6 on GWL.f_Log_Bdct_hour (meas_hour);

Alter table GWL.f_Log_Bdct_hour
add constraint lgbd_1
foreign key (Log_Bdct_id)
references GWL.d_Log_Bdct (Log_Bdct_id);

Alter table GWL.f_Log_Bdct_hour
add constraint serv_29
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Log_Bdct_hour
add constraint vers_29
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_Log_Bdct_hour
add constraint host_29
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Log_Bdct_hour
add constraint lgmt_1
foreign key (metric_id)
references GWL.d_Log_Bdct_metric (metric_id);       

--Staging hour fact table
create table GWL.stg_Log_Bdct_hr (
 msmt_id		   integer	  not null,
 orig_Log_Bdct_id            integer        not null,
 orig_Server_id		   integer	not null,
 Sv_Version		   varchar(254) not null,
 orig_host_id              integer        not null,
 orig_metric_id            integer        not null,
 cdw_id			   integer        not null	,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

-----------------------------
-- Daily Fact Table: Log_Bdct 
-----------------------------

create table GWL.f_Log_Bdct_day (
 Log_Bdct_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (Log_Bdct_id,
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_lgbd_day1 on GWL.f_Log_Bdct_day (Log_Bdct_id);
create index gwl.f_lgbd_day2 on GWL.f_Log_Bdct_day (Server_id);
create index gwl.f_lgbd_day3 on GWL.f_Log_Bdct_day (Sv_Version_id);
create index gwl.f_lgbd_day4 on GWL.f_Log_Bdct_day (host_id);
create index gwl.f_lgbd_day5 on GWL.f_Log_Bdct_day (metric_id);
create index gwl.f_lgbd_day6 on GWL.f_Log_Bdct_day (meas_date);

Alter table GWL.f_Log_Bdct_day
add constraint lgbd_2
foreign key (Log_Bdct_id)
references GWL.d_Log_Bdct (Log_Bdct_id);

Alter table GWL.f_Log_Bdct_day
add constraint serv_30
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Log_Bdct_day
add constraint vers_30
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_Log_Bdct_day
add constraint host_30
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Log_Bdct_day
add constraint lgmt_2
foreign key (metric_id)
references GWL.d_Log_Bdct_metric (metric_id);        


-----------------------------
-- Weekly Fact Table: Log_Bdct 
-----------------------------

create table GWL.f_Log_Bdct_week (
 Log_Bdct_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (Log_Bdct_id,
	Server_id,
	Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_lgbd_wk1 on GWL.f_Log_Bdct_week (Log_Bdct_id);
create index gwl.f_lgbd_wk2 on GWL.f_Log_Bdct_week (Server_id);
create index gwl.f_lgbd_wk3 on GWL.f_Log_Bdct_week (Sv_Version_id);
create index gwl.f_lgbd_wk4 on GWL.f_Log_Bdct_week (host_id);
create index gwl.f_lgbd_wk5 on GWL.f_Log_Bdct_week (metric_id);
create index gwl.f_lgbd_wk6 on GWL.f_Log_Bdct_week (meas_date);

Alter table GWL.f_Log_Bdct_week
add constraint lgbd_3
foreign key (Log_Bdct_id)
references GWL.d_Log_Bdct (Log_Bdct_id);

Alter table GWL.f_Log_Bdct_week
add constraint serv_31
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Log_Bdct_week
add constraint vers_31
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_Log_Bdct_week
add constraint host_31
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Log_Bdct_week
add constraint lgmt_3
foreign key (metric_id)
references GWL.d_Log_Bdct_metric (metric_id); 

-----------------------------
-- Monthly Fact Table: Log_Bdct 
-----------------------------

create table GWL.f_Log_Bdct_month (
 Log_Bdct_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (Log_Bdct_id,
	Server_id,
	Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_lgbd_mo1 on GWL.f_Log_Bdct_month (Log_Bdct_id);
create index gwl.f_lgbd_mo2 on GWL.f_Log_Bdct_month (Server_id);
create index gwl.f_lgbd_mo3 on GWL.f_Log_Bdct_month (Sv_Version_id);
create index gwl.f_lgbd_mo4 on GWL.f_Log_Bdct_month (host_id);
create index gwl.f_lgbd_mo5 on GWL.f_Log_Bdct_month (metric_id);
create index gwl.f_lgbd_mo6 on GWL.f_Log_Bdct_month (meas_date);

Alter table GWL.f_Log_Bdct_month
add constraint lgbd_4
foreign key (Log_Bdct_id)
references GWL.d_Log_Bdct (Log_Bdct_id);

Alter table GWL.f_Log_Bdct_month
add constraint serv__32
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Log_Bdct_month
add constraint vers_32
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_Log_Bdct_month
add constraint host_32
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Log_Bdct_month
add constraint lgmt_4
foreign key (metric_id)
references GWL.d_Log_Bdct_metric (metric_id);       

--------------------
--- WebLogic JTA 
--------------------

---------------------------------
-- Dimension Table: JTA Metric 
---------------------------------

create table GWL.d_JTA_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254) not null,
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- Translation table

create table GWL.t_JTA_metric (
  orig_metric_id 		INTEGER not null,
  metric_id			INTEGER,
  cdw_id 			INTEGER not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			VARCHAR(254) not null,
  met_units 			VARCHAR(254) not null,
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--SEQUENCE      

create sequence GWL.jtmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.jtmt_i1
no cascade before insert on GWL.d_JTA_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for GWL.jtmt_id_seq;

-----------------------------
-- Dimension Table: JTA 
-----------------------------

create table GWL.d_JTA (
 JTA_id     	           integer        not null,
 JTAName                varchar(254)   not null,
      primary key (JTA_id));

-- Translation table

create table GWL.t_JTA (
 orig_JTA_id            integer        not null,
 JTA_id			integer,
 cdw_id			   integer        not null,
 JTAName                varchar(254)   not null,
      primary key (orig_JTA_id,cdw_id)
      );

--SEQUENCE      

create sequence GWL.jta_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.jta_i1
no cascade before insert on GWL.d_JTA  
referencing new as n for each row mode db2sql
set n.JTA_id = nextval for GWL.jta_id_seq;
      
-----------------------------
-- Hourly Fact Table: JTA 
-----------------------------

create table GWL.f_JTA_hour (
 JTA_id                 integer       not null,
 Server_id		   integer	  not null,
 Sv_Version_id		   integer 	  not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (JTA_id,
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_hour)
       );

create index gwl.f_jta_hr1 on GWL.f_JTA_hour (JTA_id);
create index gwl.f_jta_hr2 on GWL.f_JTA_hour (Server_id);
create index gwl.f_jta_hr3 on GWL.f_JTA_hour (Sv_Version_id);
create index gwl.f_jta_hr4 on GWL.f_JTA_hour (host_id);
create index gwl.f_jta_hr5 on GWL.f_JTA_hour (metric_id);
create index gwl.f_jta_hr6 on GWL.f_JTA_hour (meas_hour);

Alter table GWL.f_JTA_hour
add constraint jta_1
foreign key (JTA_id)
references GWL.d_JTA (JTA_id);

Alter table GWL.f_JTA_hour
add constraint serv_33
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JTA_hour
add constraint vers_33
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_JTA_hour
add constraint host_33
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JTA_hour
add constraint jtmt_1
foreign key (metric_id)
references GWL.d_JTA_metric (metric_id);       

--Staging hour fact table
create table GWL.stg_JTA_hr (
 msmt_id		   integer	  not null,
 orig_JTA_id            integer        not null,
 orig_Server_id		   integer	not null,
 Sv_Version		   varchar(254) not null,
 orig_host_id              integer        not null,
 orig_metric_id            integer        not null,
 cdw_id			   integer        not null	,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

-----------------------------
-- Daily Fact Table: JTA 
-----------------------------

create table GWL.f_JTA_day (
 JTA_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (JTA_id,
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_jta_day1 on GWL.f_JTA_day (JTA_id);
create index gwl.f_jta_day2 on GWL.f_JTA_day (Server_id);
create index gwl.f_jta_day3 on GWL.f_JTA_day (Sv_Version_id);
create index gwl.f_jta_day4 on GWL.f_JTA_day (host_id);
create index gwl.f_jta_day5 on GWL.f_JTA_day (metric_id);
create index gwl.f_jta_day6 on GWL.f_JTA_day (meas_date);

Alter table GWL.f_JTA_day
add constraint jta_2
foreign key (JTA_id)
references GWL.d_JTA (JTA_id);

Alter table GWL.f_JTA_day
add constraint serv_34
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JTA_day
add constraint vers_34
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_JTA_day
add constraint host_34
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JTA_day
add constraint jtmt_2
foreign key (metric_id)
references GWL.d_JTA_metric (metric_id);        


-----------------------------
-- Weekly Fact Table: JTA 
-----------------------------

create table GWL.f_JTA_week (
 JTA_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (JTA_id,
	Server_id,
	Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_jta_wk1 on GWL.f_JTA_week (JTA_id);
create index gwl.f_jta_wk2 on GWL.f_JTA_week (Server_id);
create index gwl.f_jta_wk3 on GWL.f_JTA_week (Sv_Version_id);
create index gwl.f_jta_wk4 on GWL.f_JTA_week (host_id);
create index gwl.f_jta_wk5 on GWL.f_JTA_week (metric_id);
create index gwl.f_jta_wk6 on GWL.f_JTA_week (meas_date);

Alter table GWL.f_JTA_week
add constraint jta_3
foreign key (JTA_id)
references GWL.d_JTA (JTA_id);

Alter table GWL.f_JTA_week
add constraint serv_35
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JTA_week
add constraint vers_35
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_JTA_week
add constraint host_35
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JTA_week
add constraint jtmt_3
foreign key (metric_id)
references GWL.d_JTA_metric (metric_id); 

-----------------------------
-- Monthly Fact Table: JTA 
-----------------------------

create table GWL.f_JTA_month (
 JTA_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (JTA_id,
	Server_id,
	Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_jta_mo1 on GWL.f_JTA_month (JTA_id);
create index gwl.f_jta_mo2 on GWL.f_JTA_month (Server_id);
create index gwl.f_jta_mo3 on GWL.f_JTA_month (Sv_Version_id);
create index gwl.f_jta_mo4 on GWL.f_JTA_month (host_id);
create index gwl.f_jta_mo5 on GWL.f_JTA_month (metric_id);
create index gwl.f_jta_mo6 on GWL.f_JTA_month (meas_date);

Alter table GWL.f_JTA_month
add constraint jta_4
foreign key (JTA_id)
references GWL.d_JTA (JTA_id);

Alter table GWL.f_JTA_month
add constraint serv_36
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JTA_month
add constraint vers_36
foreign key (Sv_Version_id)
references GWL.d_sv_Version (Sv_Version_id);

Alter table GWL.f_JTA_month
add constraint host_36
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JTA_month
add constraint jtmt_4
foreign key (metric_id)
references GWL.d_JTA_metric (metric_id);       


--------------------
--- WebLogic JVM 
--------------------

---------------------------------
-- Dimension Table: JVM Metric 
---------------------------------

create table GWL.d_JVM_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254) not null,
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- Translation table

create table GWL.t_JVM_metric (
  orig_metric_id 		INTEGER not null,
  metric_id			INTEGER,
  cdw_id 			INTEGER not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			VARCHAR(254) not null,
  met_units 			VARCHAR(254) not null,
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--SEQUENCE      

create sequence GWL.jmmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.jmmt_i1
no cascade before insert on GWL.d_JVM_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for GWL.jmmt_id_seq;

-----------------------------
-- Dimension Table: JVM 
-----------------------------

create table GWL.d_JVM (
 JVM_id     	           integer        not null,
 JVMName                varchar(254)   not null,
      primary key (JVM_id));

-- Translation table

create table GWL.t_JVM (
 orig_JVM_id            integer        not null,
 JVM_id			integer,
 cdw_id			   integer        not null,
 JVMName                varchar(254)   not null,
      primary key (orig_JVM_id,cdw_id)
      );

--SEQUENCE      

create sequence GWL.jvm_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.jvm_i1
no cascade before insert on GWL.d_JVM  
referencing new as n for each row mode db2sql
set n.JVM_id = nextval for GWL.jvm_id_seq;
      
     
-----------------------------
-- Dimension Table:JVMVersion 
-----------------------------

create table GWL.d_jm_JVMVersion (
 JVMVersion_id    	           integer        not null,
 JVMVersion                   varchar(254)   not null,
      primary key (JVMVersion_id));

--SEQUENCE      

create sequence GWL.jvvs_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.jvvs_i1
no cascade before insert on GWL.d_jm_JVMVersion 
referencing new as n for each row mode db2sql
set n.JVMVersion_id = nextval for GWL.jvvs_id_seq;     
      
-----------------------------
-- Dimension Table: JVMVendor 
-----------------------------

create table GWL.d_jm_JVMVendor (
 JVMVendor_id    	      integer        not null,
 JVMVendor                   varchar(254)   not null,
      primary key (JVMVendor_id));

--SEQUENCE      

create sequence GWL.jvvd_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.jvvd_i1
no cascade before insert on GWL.d_jm_JVMVendor 
referencing new as n for each row mode db2sql
set n.JVMVendor_id = nextval for GWL.jvvd_id_seq;     
      
-----------------------------
-- Hourly Fact Table: JVM 
-----------------------------

create table GWL.f_JVM_hour (
 JVM_id                 integer        not null,
 JVMVersion_id         	   integer        not null, 
 JVMVendor_id          integer	  not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	  not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (JVM_id,
       JVMVersion_id, JVMVendor_id,
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_hour)
       );

create index gwl.f_jvm_hr1 on GWL.f_JVM_hour (JVM_id);
create index gwl.f_jvm_hr2 on GWL.f_JVM_hour (JVMVersion_id);
create index gwl.f_jvm_hr3 on GWL.f_JVM_hour (JVMVendor_id);
create index gwl.f_jvm_hr4 on GWL.f_JVM_hour (Server_id);
create index gwl.f_jvm_hr5 on GWL.f_JVM_hour (Sv_Version_id);
create index gwl.f_jvm_hr6 on GWL.f_JVM_hour (host_id);
create index gwl.f_jvm_hr7 on GWL.f_JVM_hour (metric_id);
create index gwl.f_jvm_hr8 on GWL.f_JVM_hour (meas_hour);

Alter table GWL.f_JVM_hour
add constraint jvm_1
foreign key (JVM_id)
references GWL.d_JVM (JVM_id);

Alter table GWL.f_JVM_hour
add constraint jvvs_1
foreign key (JVMVersion_id)
references GWL.d_jm_JVMVersion (JVMVersion_id);

Alter table GWL.f_JVM_hour
add constraint jvvd_1
foreign key (JVMVendor_id)
references GWL.d_jm_JVMVendor (JVMVendor_id);

Alter table GWL.f_JVM_hour
add constraint serv_37
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JVM_hour
add constraint vers_37
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_JVM_hour
add constraint host_37
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JVM_hour
add constraint jmmt_1
foreign key (metric_id)
references GWL.d_JVM_metric (metric_id);       

--Staging hour fact table
create table GWL.stg_JVM_hr (
 msmt_id		   integer	  not null,
 orig_JVM_id            integer        not null,
 JVMVersion         	   varchar(254)   not null,
 JVMVendor                varchar(254)   not null,
 orig_Server_id		   integer	  not null,
 Sv_Version		   varchar(254)   not null,
 orig_host_id              integer        not null,
 orig_metric_id            integer        not null,
 cdw_id			   integer        not null	,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

-----------------------------
-- Daily Fact Table: JVM 
-----------------------------

create table GWL.f_JVM_day (
 JVM_id                 integer        not null,
 JVMVersion_id		   integer	  not null,
 JVMVendor_id	           integer 	  not null,
 Server_id		   integer	not null,
 Sv_Version_id             integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (JVM_id,
       JVMVersion_id, JVMVendor_id,
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_jvm_day1 on GWL.f_JVM_day (JVM_id);
create index gwl.f_jvm_day2 on GWL.f_JVM_day (JVMVersion_id);
create index gwl.f_jvm_day3 on GWL.f_JVM_day (JVMVendor_id);
create index gwl.f_jvm_day4 on GWL.f_JVM_day (Server_id);
create index gwl.f_jvm_day5 on GWL.f_JVM_day (Sv_Version_id);
create index gwl.f_jvm_day6 on GWL.f_JVM_day (host_id);
create index gwl.f_jvm_day7 on GWL.f_JVM_day (metric_id);
create index gwl.f_jvm_day8 on GWL.f_JVM_day (meas_date);

Alter table GWL.f_JVM_day
add constraint jvm_2
foreign key (JVM_id)
references GWL.d_JVM (JVM_id);

Alter table GWL.f_JVM_day
add constraint jvvs_2
foreign key (JVMVersion_id)
references GWL.d_jm_JVMVersion (JVMVersion_id);

Alter table GWL.f_JVM_day
add constraint jvvd_2
foreign key (JVMVendor_id)
references GWL.d_jm_JVMVendor (JVMVendor_id);

Alter table GWL.f_JVM_day
add constraint serv_38
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JVM_day
add constraint vers_38
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_JVM_day
add constraint host_38
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JVM_day
add constraint jmmt_2
foreign key (metric_id)
references GWL.d_JVM_metric (metric_id);        


-----------------------------
-- Weekly Fact Table: JVM 
-----------------------------

create table GWL.f_JVM_week (
 JVM_id                 integer        not null,
 JVMVersion_id		   integer	  not null,
 JVMVendor_id	           integer 	  not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (JVM_id,
       JVMVersion_id, JVMVendor_id, 
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_jvm_wk1 on GWL.f_JVM_week (JVM_id);
create index gwl.f_jvm_wk2 on GWL.f_JVM_week (JVMVersion_id);
create index gwl.f_jvm_wk3 on GWL.f_JVM_week (JVMVendor_id);
create index gwl.f_jvm_wk4 on GWL.f_JVM_week (Server_id);
create index gwl.f_jvm_wk5 on GWL.f_JVM_week (Sv_Version_id);
create index gwl.f_jvm_wk6 on GWL.f_JVM_week (host_id);
create index gwl.f_jvm_wk7 on GWL.f_JVM_week (metric_id);
create index gwl.f_jvm_wk8 on GWL.f_JVM_week (meas_date);

Alter table GWL.f_JVM_week
add constraint jvm_3
foreign key (JVM_id)
references GWL.d_JVM (JVM_id);

Alter table GWL.f_JVM_week
add constraint jvvs_3
foreign key (JVMVersion_id)
references GWL.d_jm_JVMVersion (JVMVersion_id);

Alter table GWL.f_JVM_week
add constraint jvvd_3
foreign key (JVMVendor_id)
references GWL.d_jm_JVMVendor (JVMVendor_id);

Alter table GWL.f_JVM_week
add constraint serv_39
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JVM_week
add constraint vers_39
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_JVM_week
add constraint host_39
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JVM_week
add constraint jmmt_3
foreign key (metric_id)
references GWL.d_JVM_metric (metric_id); 

-----------------------------
-- Monthly Fact Table: JVM 
-----------------------------

create table GWL.f_JVM_month (
 JVM_id                 integer        not null,
 JVMVersion_id		   integer	  not null,
 JVMVendor_id	           integer 	  not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (JVM_id,
       JVMVersion_id, JVMVendor_id, 
       Server_id,
       Sv_Version_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_jvm_mo1 on GWL.f_JVM_month (JVM_id);
create index gwl.f_jvm_mo2 on GWL.f_JVM_month (JVMVersion_id);
create index gwl.f_jvm_mo3 on GWL.f_JVM_month (JVMVendor_id);
create index gwl.f_jvm_mo4 on GWL.f_JVM_month (Server_id);
create index gwl.f_jvm_mo5 on GWL.f_JVM_month (Sv_Version_id);
create index gwl.f_jvm_mo6 on GWL.f_JVM_month (host_id);
create index gwl.f_jvm_mo7 on GWL.f_JVM_month (metric_id);
create index gwl.f_jvm_mo8 on GWL.f_JVM_month (meas_date);

Alter table GWL.f_JVM_month
add constraint jvm_4
foreign key (JVM_id)
references GWL.d_JVM (JVM_id);

Alter table GWL.f_JVM_month
add constraint jvvs_4
foreign key (JVMVersion_id)
references GWL.d_jm_JVMVersion (JVMVersion_id);

Alter table GWL.f_JVM_month
add constraint jvvd_4
foreign key (JVMVendor_id)
references GWL.d_jm_JVMVendor (JVMVendor_id);

Alter table GWL.f_JVM_month
add constraint serv_40
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JVM_month
add constraint vers_40
foreign key (Sv_Version_id)
references GWL.d_Sv_version (Sv_version_id);

Alter table GWL.f_JVM_month
add constraint host_40
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JVM_month
add constraint jmmt_4
foreign key (metric_id)
references GWL.d_JVM_metric (metric_id);       


--------------------
--- WebLogic Tx_Res 
--------------------

---------------------------------
-- Dimension Table: Tx_Res Metric 
---------------------------------

create table GWL.d_Tx_Res_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254) not null,
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- Translation table

create table GWL.t_Tx_Res_metric (
  orig_metric_id 		INTEGER not null,
  metric_id			INTEGER,
  cdw_id 			INTEGER not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			VARCHAR(254) not null,
  met_units 			VARCHAR(254) not null,
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--SEQUENCE      

create sequence GWL.trmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.trmt_i1
no cascade before insert on GWL.d_Tx_Res_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for GWL.trmt_id_seq;

-----------------------------
-- Dimension Table: Tx_Res 
-----------------------------

create table GWL.d_Tx_Res (
 Tx_Res_id     	           integer        not null,
 TxResName                varchar(254)   not null,
      primary key (Tx_Res_id));

-- Translation table

create table GWL.t_Tx_Res (
 orig_Tx_Res_id            integer        not null,
 Tx_Res_id		   integer,
 cdw_id			   integer        not null,
 TxResName                varchar(254)   not null,
      primary key (orig_Tx_Res_id,cdw_id)
      );

--SEQUENCE      

create sequence GWL.txrs_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.txrs_i1
no cascade before insert on GWL.d_Tx_Res  
referencing new as n for each row mode db2sql
set n.Tx_Res_id = nextval for GWL.txrs_id_seq;
      
-----------------------------
-- Hourly Fact Table: Tx_Res 
-----------------------------

create table GWL.f_Tx_Res_hour (
 Tx_Res_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 JTA_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (Tx_Res_id,
       Server_id,
       Sv_Version_id,
       JTA_id,
       host_id, metric_id, 
       meas_hour)
       );

create index gwl.f_txrs_hr1 on GWL.f_Tx_Res_hour (Tx_Res_id);
create index gwl.f_txrs_hr2 on GWL.f_Tx_Res_hour (Server_id);
create index gwl.f_txrs_hr3 on GWL.f_Tx_Res_hour (Sv_Version_id);
create index gwl.f_txrs_hr4 on GWL.f_Tx_Res_hour (JTA_id);
create index gwl.f_txrs_hr5 on GWL.f_Tx_Res_hour (host_id);
create index gwl.f_txrs_hr6 on GWL.f_Tx_Res_hour (metric_id);
create index gwl.f_txrs_hr7 on GWL.f_Tx_Res_hour (meas_hour);

Alter table GWL.f_Tx_Res_hour
add constraint txrs_1
foreign key (Tx_Res_id)
references GWL.d_Tx_Res (Tx_Res_id);

Alter table GWL.f_Tx_Res_hour
add constraint serv_41
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Tx_Res_hour
add constraint vers_41
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_Tx_Res_hour
add constraint jta_5
foreign key (JTA_id)
references GWL.d_JTA (JTA_id);

Alter table GWL.f_Tx_Res_hour
add constraint host_41
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Tx_Res_hour
add constraint trmt_1
foreign key (metric_id)
references GWL.d_Tx_Res_metric (metric_id);       

--Staging hour fact table
create table GWL.stg_Tx_Res_hr (
 msmt_id		   integer	  not null,
 orig_Tx_Res_id            integer        not null,
 orig_Server_id		   integer	not null,
 Sv_Version                varchar(254) not null,
 orig_JTA_id		   integer	not null,
 orig_host_id              integer        not null,
 orig_metric_id            integer        not null,
 cdw_id			   integer        not null	,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

-----------------------------
-- Daily Fact Table: Tx_Res 
-----------------------------

create table GWL.f_Tx_Res_day (
 Tx_Res_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 JTA_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (Tx_Res_id,
       Server_id,
       Sv_Version_id,
       JTA_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_txrs_day1 on GWL.f_Tx_Res_day (Tx_Res_id);
create index gwl.f_txrs_day2 on GWL.f_Tx_Res_day (Server_id);
create index gwl.f_txrs_day3 on GWL.f_Tx_Res_day (Sv_Version_id);
create index gwl.f_txrs_day4 on GWL.f_Tx_Res_day (JTA_id);
create index gwl.f_txrs_day5 on GWL.f_Tx_Res_day (host_id);
create index gwl.f_txrs_day6 on GWL.f_Tx_Res_day (metric_id);
create index gwl.f_txrs_day7 on GWL.f_Tx_Res_day (meas_date);

Alter table GWL.f_Tx_Res_day
add constraint txrs_2
foreign key (Tx_Res_id)
references GWL.d_Tx_Res (Tx_Res_id);

Alter table GWL.f_Tx_Res_day
add constraint serv_42
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Tx_Res_day
add constraint vers_42
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_Tx_Res_day
add constraint jta_6
foreign key (JTA_id)
references GWL.d_JTA (JTA_id);

Alter table GWL.f_Tx_Res_day
add constraint host_42
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Tx_Res_day
add constraint trmt_2
foreign key (metric_id)
references GWL.d_Tx_Res_metric (metric_id);        


-----------------------------
-- Weekly Fact Table: Tx_Res 
-----------------------------

create table GWL.f_Tx_Res_week (
 Tx_Res_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 JTA_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (Tx_Res_id,
	Server_id,
	Sv_Version_id,
	JTA_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_txrs_wk1 on GWL.f_Tx_Res_week (Tx_Res_id);
create index gwl.f_txrs_wk2 on GWL.f_Tx_Res_week (Server_id);
create index gwl.f_txrs_wk3 on GWL.f_Tx_Res_week (Sv_Version_id);
create index gwl.f_txrs_wk4 on GWL.f_Tx_Res_week (JTA_id);
create index gwl.f_txrs_wk5 on GWL.f_Tx_Res_week (host_id);
create index gwl.f_txrs_wk6 on GWL.f_Tx_Res_week (metric_id);
create index gwl.f_txrs_wk7 on GWL.f_Tx_Res_week (meas_date);

Alter table GWL.f_Tx_Res_week
add constraint txrs_3
foreign key (Tx_Res_id)
references GWL.d_Tx_Res (Tx_Res_id);

Alter table GWL.f_Tx_Res_week
add constraint serv_43
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Tx_Res_week
add constraint vers_43
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_Tx_Res_week
add constraint jta_7
foreign key (JTA_id)
references GWL.d_JTA (JTA_id);

Alter table GWL.f_Tx_Res_week
add constraint host_43
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Tx_Res_week
add constraint trmt_3
foreign key (metric_id)
references GWL.d_Tx_Res_metric (metric_id); 

-----------------------------
-- Monthly Fact Table: Tx_Res 
-----------------------------

create table GWL.f_Tx_Res_month (
 Tx_Res_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 JTA_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (Tx_Res_id,
	Server_id,
	Sv_Version_id,
	JTA_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_txrs_mo1 on GWL.f_Tx_Res_month (Tx_Res_id);
create index gwl.f_txrs_mo2 on GWL.f_Tx_Res_month (Server_id);
create index gwl.f_txrs_mo3 on GWL.f_Tx_Res_month (Sv_Version_id);
create index gwl.f_txrs_mo4 on GWL.f_Tx_Res_month (JTA_id);
create index gwl.f_txrs_mo5 on GWL.f_Tx_Res_month (host_id);
create index gwl.f_txrs_mo6 on GWL.f_Tx_Res_month (metric_id);
create index gwl.f_txrs_mo7 on GWL.f_Tx_Res_month (meas_date);

Alter table GWL.f_Tx_Res_month
add constraint txrs_4
foreign key (Tx_Res_id)
references GWL.d_Tx_Res (Tx_Res_id);

Alter table GWL.f_Tx_Res_month
add constraint serv_44
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Tx_Res_month
add constraint vers_44
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_Tx_Res_month
add constraint jta_8
foreign key (JTA_id)
references GWL.d_JTA (JTA_id);

Alter table GWL.f_Tx_Res_month
add constraint host_44
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Tx_Res_month
add constraint trmt_4
foreign key (metric_id)
references GWL.d_Tx_Res_metric (metric_id);       

--------------------
--- WebLogic JMS_Dest 
--------------------

---------------------------------
-- Dimension Table: JMS_Dest Metric 
---------------------------------

create table GWL.d_JMS_Dest_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254) not null,
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- Translation table

create table GWL.t_JMS_Dest_metric (
  orig_metric_id 		INTEGER not null,
  metric_id			INTEGER,
  cdw_id 			INTEGER not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			VARCHAR(254) not null,
  met_units 			VARCHAR(254) not null,
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--SEQUENCE      

create sequence GWL.jdmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.jdmt_i1
no cascade before insert on GWL.d_JMS_Dest_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for GWL.jdmt_id_seq;

-----------------------------
-- Dimension Table: JMS_Dest 
-----------------------------

create table GWL.d_JMS_Dest (
 JMS_Dest_id     	           integer        not null,
 JMSDestName                varchar(254)   not null,
 JMSDestType                   varchar(254)   not null,
      primary key (JMS_Dest_id));

-- Translation table

create table GWL.t_JMS_Dest (
 orig_JMS_Dest_id            integer        not null,
 JMS_Dest_id		   integer,
 cdw_id			   integer        not null,
 JMSDestName                varchar(254)   not null,
 JMSDestType                   varchar(254)   not null,
      primary key (orig_JMS_Dest_id,cdw_id)
      );

--SEQUENCE      

create sequence GWL.jmsd_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.jmsd_i1
no cascade before insert on GWL.d_JMS_Dest  
referencing new as n for each row mode db2sql
set n.JMS_Dest_id = nextval for GWL.jmsd_id_seq;
      
     
-----------------------------
-- Hourly Fact Table: JMS_Dest 
-----------------------------

create table GWL.f_JMS_Dest_hour (
 JMS_Dest_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 JMSSrv_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (JMS_Dest_id,
       Server_id,
       Sv_Version_id,
       JMSSrv_id,
       host_id, metric_id, 
       meas_hour)
       );

create index gwl.f_jmsd_hr1 on GWL.f_JMS_Dest_hour (JMS_Dest_id);
create index gwl.f_jmsd_hr2 on GWL.f_JMS_Dest_hour (Server_id);
create index gwl.f_jmsd_hr3 on GWL.f_JMS_Dest_hour (Sv_Version_id);
create index gwl.f_jmsd_hr4 on GWL.f_JMS_Dest_hour (JMSSrv_id);
create index gwl.f_jmsd_hr5 on GWL.f_JMS_Dest_hour (host_id);
create index gwl.f_jmsd_hr6 on GWL.f_JMS_Dest_hour (metric_id);
create index gwl.f_jmsd_hr7 on GWL.f_JMS_Dest_hour (meas_hour);

Alter table GWL.f_JMS_Dest_hour
add constraint jmsd_1
foreign key (JMS_Dest_id)
references GWL.d_JMS_Dest (JMS_Dest_id);

Alter table GWL.f_JMS_Dest_hour
add constraint serv_45
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JMS_Dest_hour
add constraint  vers_45
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_JMS_Dest_hour
add constraint jmss_5
foreign key (JMSSrv_id)
references GWL.d_JMSSrv (JMSSrv_id);

Alter table GWL.f_JMS_Dest_hour
add constraint host_45
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JMS_Dest_hour
add constraint jdmt_1
foreign key (metric_id)
references GWL.d_JMS_Dest_metric (metric_id);       

--Staging hour fact table
create table GWL.stg_JMS_Dest_hr (
 msmt_id		   integer	  not null,
 orig_JMS_Dest_id            integer        not null,
 orig_Server_id		   integer	not null,
 Sv_Version         	   varchar(254)   not null,
 orig_JMSSrv_id		   integer	not null,
 orig_host_id              integer        not null,
 orig_metric_id            integer        not null,
 cdw_id			   integer        not null	,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

-----------------------------
-- Daily Fact Table: JMS_Dest 
-----------------------------

create table GWL.f_JMS_Dest_day (
 JMS_Dest_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	  not null,
 JMSSrv_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (JMS_Dest_id,
       Server_id,
       Sv_Version_id,
       JMSSrv_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_jmsd_day1 on GWL.f_JMS_Dest_day (JMS_Dest_id);
create index gwl.f_jmsd_day2 on GWL.f_JMS_Dest_day (Server_id);
create index gwl.f_jmsd_day3 on GWL.f_JMS_Dest_day (Sv_Version_id);
create index gwl.f_jmsd_day4 on GWL.f_JMS_Dest_day (JMSSrv_id);
create index gwl.f_jmsd_day5 on GWL.f_JMS_Dest_day (host_id);
create index gwl.f_jmsd_day6 on GWL.f_JMS_Dest_day (metric_id);
create index gwl.f_jmsd_day7 on GWL.f_JMS_Dest_day (meas_date);

Alter table GWL.f_JMS_Dest_day
add constraint jmsd_2
foreign key (JMS_Dest_id)
references GWL.d_JMS_Dest (JMS_Dest_id);


Alter table GWL.f_JMS_Dest_day
add constraint serv_46
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JMS_Dest_day
add constraint vers_46
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_JMS_Dest_day
add constraint jmss_6
foreign key (JMSSrv_id)
references GWL.d_JMSSrv (JMSSrv_id);

Alter table GWL.f_JMS_Dest_day
add constraint host_46
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JMS_Dest_day
add constraint jdmt_2
foreign key (metric_id)
references GWL.d_JMS_Dest_metric (metric_id);        


-----------------------------
-- Weekly Fact Table: JMS_Dest 
-----------------------------

create table GWL.f_JMS_Dest_week (
 JMS_Dest_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	  not null,
 JMSSrv_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (JMS_Dest_id,
       Server_id,
       Sv_Version_id, 
       JMSSrv_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_jmsd_wk1 on GWL.f_JMS_Dest_week (JMS_Dest_id);
create index gwl.f_jmsd_wk2 on GWL.f_JMS_Dest_week (Server_id);
create index gwl.f_jmsd_wk3 on GWL.f_JMS_Dest_week (Sv_Version_id);
create index gwl.f_jmsd_wk4 on GWL.f_JMS_Dest_week (JMSSrv_id);
create index gwl.f_jmsd_wk5 on GWL.f_JMS_Dest_week (host_id);
create index gwl.f_jmsd_wk6 on GWL.f_JMS_Dest_week (metric_id);
create index gwl.f_jmsd_wk7 on GWL.f_JMS_Dest_week (meas_date);

Alter table GWL.f_JMS_Dest_week
add constraint jmsd_3
foreign key (JMS_Dest_id)
references GWL.d_JMS_Dest (JMS_Dest_id);


Alter table GWL.f_JMS_Dest_week
add constraint serv_47
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JMS_Dest_week
add constraint vers_47
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_JMS_Dest_week
add constraint jmss_7
foreign key (JMSSrv_id)
references GWL.d_JMSSrv (JMSSrv_id);

Alter table GWL.f_JMS_Dest_week
add constraint host_47
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JMS_Dest_week
add constraint jdmt_3
foreign key (metric_id)
references GWL.d_JMS_Dest_metric (metric_id); 

-----------------------------
-- Monthly Fact Table: JMS_Dest 
-----------------------------

create table GWL.f_JMS_Dest_month (
 JMS_Dest_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	  not null,
 JMSSrv_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (JMS_Dest_id,
       Server_id,
       Sv_Version_id,
       JMSSrv_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_jmsd_mo1 on GWL.f_JMS_Dest_month (JMS_Dest_id);
create index gwl.f_jmsd_mo2 on GWL.f_JMS_Dest_month (Server_id);
create index gwl.f_jmsd_mo3 on GWL.f_JMS_Dest_month (Sv_Version_id);
create index gwl.f_jmsd_mo4 on GWL.f_JMS_Dest_month (JMSSrv_id);
create index gwl.f_jmsd_mo5 on GWL.f_JMS_Dest_month (host_id);
create index gwl.f_jmsd_mo6 on GWL.f_JMS_Dest_month (metric_id);
create index gwl.f_jmsd_mo7 on GWL.f_JMS_Dest_month (meas_date);

Alter table GWL.f_JMS_Dest_month
add constraint jmsd_4
foreign key (JMS_Dest_id)
references GWL.d_JMS_Dest (JMS_Dest_id);


Alter table GWL.f_JMS_Dest_month
add constraint serv_48
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_JMS_Dest_month
add constraint vers_48
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_JMS_Dest_month
add constraint jmss_8
foreign key (JMSSrv_id)
references GWL.d_JMSSrv (JMSSrv_id);

Alter table GWL.f_JMS_Dest_month
add constraint host_48
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_JMS_Dest_month
add constraint jdmt_4
foreign key (metric_id)
references GWL.d_JMS_Dest_metric (metric_id);       

--------------------
--- WebLogic Cnt_Comp 
--------------------

---------------------------------
-- Dimension Table: Cnt_Comp Metric 
---------------------------------

create table GWL.d_Cnt_Comp_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254) not null,
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- Translation table

create table GWL.t_Cnt_Comp_metric (
  orig_metric_id 		INTEGER not null,
  metric_id			INTEGER,
  cdw_id 			INTEGER not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			VARCHAR(254) not null,
  met_units 			VARCHAR(254) not null,
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--SEQUENCE      

create sequence GWL.ccmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.ccmt_i1
no cascade before insert on GWL.d_Cnt_Comp_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for GWL.ccmt_id_seq;

-----------------------------
-- Dimension Table: Cnt_Comp 
-----------------------------

create table GWL.d_Cnt_Comp (
 Cnt_Comp_id            integer        not null,
 CntCompName                varchar(254)   not null,
 DisplayName                   varchar(254)   not null,
 CntFactName                   varchar(254)   not null,
 PoolName                   varchar(254)   not null,
      primary key (Cnt_Comp_id));

-- Translation table

create table GWL.t_Cnt_Comp (
 orig_Cnt_Comp_id       integer        not null,
 Cnt_Comp_id		integer,
 cdw_id		       integer        not null,
 CntCompName                varchar(254)   not null,
 DisplayName                   varchar(254)   not null,
 CntFactName                   varchar(254)   not null,
 PoolName                   varchar(254)   not null,
      primary key (orig_Cnt_Comp_id,cdw_id)
      );

--SEQUENCE      

create sequence GWL.ctcp_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.ctcp_i1
no cascade before insert on GWL.d_Cnt_Comp  
referencing new as n for each row mode db2sql
set n.Cnt_Comp_id = nextval for GWL.ctcp_id_seq;
      
     
-----------------------------
-- Hourly Fact Table: Cnt_Comp 
-----------------------------

create table GWL.f_Cnt_Comp_hour (
 Cnt_Comp_id                integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id	           integer        not null,
 Appl_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (Cnt_Comp_id,
       Server_id,
       Sv_Version_id,
       Appl_id,
       host_id, metric_id, 
       meas_hour)
       );

create index gwl.f_ctcp_hr1 on GWL.f_Cnt_Comp_hour (Cnt_Comp_id);
create index gwl.f_ctcp_hr2 on GWL.f_Cnt_Comp_hour (Server_id);
create index gwl.f_ctcp_hr3 on GWL.f_Cnt_Comp_hour (Sv_Version_id);
create index gwl.f_ctcp_hr4 on GWL.f_Cnt_Comp_hour (Appl_id);
create index gwl.f_ctcp_hr5 on GWL.f_Cnt_Comp_hour (host_id);
create index gwl.f_ctcp_hr6 on GWL.f_Cnt_Comp_hour (metric_id);
create index gwl.f_ctcp_hr7 on GWL.f_Cnt_Comp_hour (meas_hour);

Alter table GWL.f_Cnt_Comp_hour
add constraint ctcp_1
foreign key (Cnt_Comp_id)
references GWL.d_Cnt_Comp (Cnt_Comp_id);

Alter table GWL.f_Cnt_Comp_hour
add constraint serv_49
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Cnt_Comp_hour
add constraint vers_49
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_Cnt_Comp_hour
add constraint appl_5
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_Cnt_Comp_hour
add constraint host_49
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Cnt_Comp_hour
add constraint ccmt_1
foreign key (metric_id)
references GWL.d_Cnt_Comp_metric (metric_id);       

--Staging hour fact table
create table GWL.stg_Cnt_Comp_hr (
 msmt_id		   integer	  not null,
 orig_Cnt_Comp_id            integer        not null,
 orig_Server_id		   integer	not null,
 Sv_Version	           varchar(254)   not null,
 orig_Appl_id		   integer	not null,
 orig_host_id              integer        not null,
 orig_metric_id            integer        not null,
 cdw_id			   integer        not null	,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

-----------------------------
-- Daily Fact Table: Cnt_Comp 
-----------------------------

create table GWL.f_Cnt_Comp_day (
 Cnt_Comp_id                integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id                integer        not null,
 Appl_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (Cnt_Comp_id,
       Server_id,
       Sv_Version_id,
       Appl_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_ctcp_day1 on GWL.f_Cnt_Comp_day (Cnt_Comp_id);
create index gwl.f_ctcp_day2 on GWL.f_Cnt_Comp_day (Server_id);
create index gwl.f_ctcp_day3 on GWL.f_Cnt_Comp_day (Sv_Version_id);
create index gwl.f_ctcp_day4 on GWL.f_Cnt_Comp_day (Appl_id);
create index gwl.f_ctcp_day5 on GWL.f_Cnt_Comp_day (host_id);
create index gwl.f_ctcp_day6 on GWL.f_Cnt_Comp_day (metric_id);
create index gwl.f_ctcp_day7 on GWL.f_Cnt_Comp_day (meas_date);

Alter table GWL.f_Cnt_Comp_day
add constraint ctcp_2
foreign key (Cnt_Comp_id)
references GWL.d_Cnt_Comp (Cnt_Comp_id);

Alter table GWL.f_Cnt_Comp_day
add constraint serv_50
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Cnt_Comp_day
add constraint vers_50
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_Cnt_Comp_day
add constraint appl_6
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_Cnt_Comp_day
add constraint host_50
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Cnt_Comp_day
add constraint ccmt_2
foreign key (metric_id)
references GWL.d_Cnt_Comp_metric (metric_id);        

-----------------------------
-- Weekly Fact Table: Cnt_Comp 
-----------------------------

create table GWL.f_Cnt_Comp_week (
 Cnt_Comp_id                integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id                integer        not null,
 Appl_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (Cnt_Comp_id,
       Server_id,
       Sv_Version_id,
       Appl_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_ctcp_wk1 on GWL.f_Cnt_Comp_week (Cnt_Comp_id);
create index gwl.f_ctcp_wk2 on GWL.f_Cnt_Comp_week (Server_id);
create index gwl.f_ctcp_wk3 on GWL.f_Cnt_Comp_week (Sv_Version_id);
create index gwl.f_ctcp_wk4 on GWL.f_Cnt_Comp_week (Appl_id);
create index gwl.f_ctcp_wk5 on GWL.f_Cnt_Comp_week (host_id);
create index gwl.f_ctcp_wk6 on GWL.f_Cnt_Comp_week (metric_id);
create index gwl.f_ctcp_wk7 on GWL.f_Cnt_Comp_week (meas_date);

Alter table GWL.f_Cnt_Comp_week
add constraint ctcp_3
foreign key (Cnt_Comp_id)
references GWL.d_Cnt_Comp (Cnt_Comp_id);

Alter table GWL.f_Cnt_Comp_week
add constraint serv_51
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Cnt_Comp_week
add constraint vers_51
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_Cnt_Comp_week
add constraint appl_7
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_Cnt_Comp_week
add constraint host_51
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Cnt_Comp_week
add constraint ccmt_3
foreign key (metric_id)
references GWL.d_Cnt_Comp_metric (metric_id); 

-----------------------------
-- Monthly Fact Table: Cnt_Comp 
-----------------------------

create table GWL.f_Cnt_Comp_month (
 Cnt_Comp_id                integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id                integer        not null,
 Appl_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (Cnt_Comp_id,
        Server_id,
        Sv_Version_id,
       Appl_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_ctcp_mo1 on GWL.f_Cnt_Comp_month (Cnt_Comp_id);
create index gwl.f_ctcp_mo2 on GWL.f_Cnt_Comp_month (Server_id);
create index gwl.f_ctcp_mo3 on GWL.f_Cnt_Comp_month (Sv_Version_id);
create index gwl.f_ctcp_mo4 on GWL.f_Cnt_Comp_month (Appl_id);
create index gwl.f_ctcp_mo5 on GWL.f_Cnt_Comp_month (host_id);
create index gwl.f_ctcp_mo6 on GWL.f_Cnt_Comp_month (metric_id);
create index gwl.f_ctcp_mo7 on GWL.f_Cnt_Comp_month (meas_date);

Alter table GWL.f_Cnt_Comp_month
add constraint ctcp_4
foreign key (Cnt_Comp_id)
references GWL.d_Cnt_Comp (Cnt_Comp_id);

Alter table GWL.f_Cnt_Comp_month
add constraint serv_52
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Cnt_Comp_month
add constraint vers_52
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_Cnt_Comp_month
add constraint appl_8
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_Cnt_Comp_month
add constraint host_52
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Cnt_Comp_month
add constraint ccmt_4
foreign key (metric_id)
references GWL.d_Cnt_Comp_metric (metric_id);       

--------------------
--- WebLogic EJB_Comp 
--------------------

---------------------------------
-- Dimension Table: EJB_Comp Metric 
---------------------------------

create table GWL.d_EJB_Comp_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254) not null,
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- Translation table

create table GWL.t_EJB_Comp_metric (
  orig_metric_id 		INTEGER not null,
  metric_id			INTEGER,
  cdw_id 			INTEGER not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			VARCHAR(254) not null,
  met_units 			VARCHAR(254) not null,
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--SEQUENCE      

create sequence GWL.ecmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.ecmt_i1
no cascade before insert on GWL.d_EJB_Comp_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for GWL.ecmt_id_seq;

-----------------------------
-- Dimension Table: EJB_Comp 
-----------------------------

create table GWL.d_EJB_Comp (
 EJB_Comp_id     	           integer        not null,
 EJBCompName                varchar(254)   not null,
      primary key (EJB_Comp_id));

-- Translation table

create table GWL.t_EJB_Comp (
 orig_EJB_Comp_id            integer        not null,
 EJB_Comp_id		   integer,
 cdw_id			   integer        not null,
 EJBCompName                varchar(254)   not null,
      primary key (orig_EJB_Comp_id,cdw_id)
      );

--SEQUENCE      

create sequence GWL.ejbc_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.ejbc_i1
no cascade before insert on GWL.d_EJB_Comp  
referencing new as n for each row mode db2sql
set n.EJB_Comp_id = nextval for GWL.ejbc_id_seq;
      
-----------------------------
-- Hourly Fact Table: EJB_Comp 
-----------------------------

create table GWL.f_EJB_Comp_hour (
 EJB_Comp_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 Appl_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (EJB_Comp_id,
       Server_id,
       Sv_Version_id,
       Appl_id,
       host_id, metric_id, 
       meas_hour)
       );

create index gwl.f_ejbc_hr1 on GWL.f_EJB_Comp_hour (EJB_Comp_id);
create index gwl.f_ejbc_hr2 on GWL.f_EJB_Comp_hour (Server_id);
create index gwl.f_ejbc_hr3 on GWL.f_EJB_Comp_hour (Sv_Version_id);
create index gwl.f_ejbc_hr4 on GWL.f_EJB_Comp_hour (Appl_id);
create index gwl.f_ejbc_hr5 on GWL.f_EJB_Comp_hour (host_id);
create index gwl.f_ejbc_hr6 on GWL.f_EJB_Comp_hour (metric_id);
create index gwl.f_ejbc_hr7 on GWL.f_EJB_Comp_hour (meas_hour);

Alter table GWL.f_EJB_Comp_hour
add constraint ejbc_1
foreign key (EJB_Comp_id)
references GWL.d_EJB_Comp (EJB_Comp_id);

Alter table GWL.f_EJB_Comp_hour
add constraint serv_53
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_EJB_Comp_hour
add constraint  vers_53
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_EJB_Comp_hour
add constraint appl_9
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_EJB_Comp_hour
add constraint host_53
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_EJB_Comp_hour
add constraint ecmt_1
foreign key (metric_id)
references GWL.d_EJB_Comp_metric (metric_id);       

--Staging hour fact table
create table GWL.stg_EJB_Comp_hr (
 msmt_id		   integer	  not null,
 orig_EJB_Comp_id            integer        not null,
 orig_Server_id		   integer	not null,
 Sv_Version		   varchar(254)	not null,
 orig_Appl_id		   integer	not null,
 orig_host_id              integer        not null,
 orig_metric_id            integer        not null,
 cdw_id			   integer        not null	,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

-----------------------------
-- Daily Fact Table: EJB_Comp 
-----------------------------

create table GWL.f_EJB_Comp_day (
 EJB_Comp_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 Appl_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (EJB_Comp_id,
       Server_id,
       Sv_Version_id,
       Appl_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_ejbc_day1 on GWL.f_EJB_Comp_day (EJB_Comp_id);
create index gwl.f_ejbc_day2 on GWL.f_EJB_Comp_day (Server_id);
create index gwl.f_ejbc_day3 on GWL.f_EJB_Comp_day (Sv_Version_id);
create index gwl.f_ejbc_day4 on GWL.f_EJB_Comp_day (Appl_id);
create index gwl.f_ejbc_day5 on GWL.f_EJB_Comp_day (host_id);
create index gwl.f_ejbc_day6 on GWL.f_EJB_Comp_day (metric_id);
create index gwl.f_ejbc_day7 on GWL.f_EJB_Comp_day (meas_date);

Alter table GWL.f_EJB_Comp_day
add constraint ejbc_2
foreign key (EJB_Comp_id)
references GWL.d_EJB_Comp (EJB_Comp_id);

Alter table GWL.f_EJB_Comp_day
add constraint serv_54
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_EJB_Comp_day
add constraint vers_54
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_EJB_Comp_day
add constraint appl_10
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_EJB_Comp_day
add constraint host_54
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_EJB_Comp_day
add constraint ecmt_2
foreign key (metric_id)
references GWL.d_EJB_Comp_metric (metric_id);        


-----------------------------
-- Weekly Fact Table: EJB_Comp 
-----------------------------

create table GWL.f_EJB_Comp_week (
 EJB_Comp_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 Appl_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (EJB_Comp_id,
	Server_id,
	Sv_Version_id,
	Appl_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_ejbc_wk1 on GWL.f_EJB_Comp_week (EJB_Comp_id);
create index gwl.f_ejbc_wk2 on GWL.f_EJB_Comp_week (Server_id);
create index gwl.f_ejbc_wk3 on GWL.f_EJB_Comp_week (Sv_Version_id);
create index gwl.f_ejbc_wk4 on GWL.f_EJB_Comp_week (Appl_id);
create index gwl.f_ejbc_wk5 on GWL.f_EJB_Comp_week (host_id);
create index gwl.f_ejbc_wk6 on GWL.f_EJB_Comp_week (metric_id);
create index gwl.f_ejbc_wk7 on GWL.f_EJB_Comp_week (meas_date);

Alter table GWL.f_EJB_Comp_week
add constraint ejbc_3
foreign key (EJB_Comp_id)
references GWL.d_EJB_Comp (EJB_Comp_id);

Alter table GWL.f_EJB_Comp_week
add constraint serv_55
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_EJB_Comp_week
add constraint  vers_55
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_EJB_Comp_week
add constraint appl_11
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_EJB_Comp_week
add constraint host_55
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_EJB_Comp_week
add constraint ecmt_3
foreign key (metric_id)
references GWL.d_EJB_Comp_metric (metric_id); 

-----------------------------
-- Monthly Fact Table: EJB_Comp 
-----------------------------

create table GWL.f_EJB_Comp_month (
 EJB_Comp_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 Appl_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (EJB_Comp_id,
	Server_id,
	Sv_Version_id,
	Appl_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_ejbc_mo1 on GWL.f_EJB_Comp_month (EJB_Comp_id);
create index gwl.f_ejbc_mo2 on GWL.f_EJB_Comp_month (Server_id);
create index gwl.f_ejbc_mo3 on GWL.f_EJB_Comp_month (Sv_Version_id);
create index gwl.f_ejbc_mo4 on GWL.f_EJB_Comp_month (Appl_id);
create index gwl.f_ejbc_mo5 on GWL.f_EJB_Comp_month (host_id);
create index gwl.f_ejbc_mo6 on GWL.f_EJB_Comp_month (metric_id);
create index gwl.f_ejbc_mo7 on GWL.f_EJB_Comp_month (meas_date);

Alter table GWL.f_EJB_Comp_month
add constraint ejbc_4
foreign key (EJB_Comp_id)
references GWL.d_EJB_Comp (EJB_Comp_id);

Alter table GWL.f_EJB_Comp_month
add constraint serv_56
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_EJB_Comp_month
add constraint vers_56
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_EJB_Comp_month
add constraint appl_12
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_EJB_Comp_month
add constraint host_56
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_EJB_Comp_month
add constraint ecmt_4
foreign key (metric_id)
references GWL.d_EJB_Comp_metric (metric_id);       

--------------------
--- WebLogic WAP_COMP 
--------------------

---------------------------------
-- Dimension Table: WAP_COMP Metric 
---------------------------------

create table GWL.d_WAP_COMP_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254) not null,
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- Translation table

create table GWL.t_WAP_COMP_metric (
  orig_metric_id 		INTEGER not null,
  metric_id			INTEGER,
  cdw_id 			INTEGER not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			VARCHAR(254) not null,
  met_units 			VARCHAR(254) not null,
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--SEQUENCE      

create sequence GWL.wpmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.wpmt_i1
no cascade before insert on GWL.d_WAP_COMP_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for GWL.wpmt_id_seq;

-----------------------------
-- Dimension Table: WAP_COMP 
-----------------------------

create table GWL.d_WAP_COMP (
 WAP_COMP_id     	           integer        not null,
 WAPCompName                varchar(254)   not null,
 SourceInfo                   varchar(254)   not null,
      primary key (WAP_COMP_id));

-- Translation table

create table GWL.t_WAP_COMP (
 orig_WAP_COMP_id            integer        not null,
 WAP_COMP_id		   integer,
 cdw_id			   integer        not null,
 WAPCompName                varchar(254)   not null,
 SourceInfo                   varchar(254)   not null,
      primary key (orig_WAP_COMP_id,cdw_id)
      );

--SEQUENCE      

create sequence GWL.wpcp_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.wpcp_i1
no cascade before insert on GWL.d_WAP_COMP  
referencing new as n for each row mode db2sql
set n.WAP_COMP_id = nextval for GWL.wpcp_id_seq;
      
     
-----------------------------
-- Hourly Fact Table: WAP_COMP 
-----------------------------

create table GWL.f_WAP_COMP_hour (
 WAP_COMP_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id         	   integer        not null, 
 Appl_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (WAP_COMP_id,
       Server_id,
       Sv_Version_id, 
       Appl_id,
       host_id, metric_id, 
       meas_hour)
       );

create index gwl.f_wpcp_hr1 on GWL.f_WAP_COMP_hour (WAP_COMP_id);
create index gwl.f_wpcp_hr2 on GWL.f_WAP_COMP_hour (Server_id);
create index gwl.f_wpcp_hr3 on GWL.f_WAP_COMP_hour (Sv_Version_id);
create index gwl.f_wpcp_hr4 on GWL.f_WAP_COMP_hour (Appl_id);
create index gwl.f_wpcp_hr5 on GWL.f_WAP_COMP_hour (host_id);
create index gwl.f_wpcp_hr6 on GWL.f_WAP_COMP_hour (metric_id);
create index gwl.f_wpcp_hr7 on GWL.f_WAP_COMP_hour (meas_hour);

Alter table GWL.f_WAP_COMP_hour
add constraint wpcp_1
foreign key (WAP_COMP_id)
references GWL.d_WAP_COMP (WAP_COMP_id);

Alter table GWL.f_WAP_COMP_hour
add constraint serv_57
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_WAP_COMP_hour
add constraint vers_57
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_WAP_COMP_hour
add constraint appl_13
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_WAP_COMP_hour
add constraint host_57
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_WAP_COMP_hour
add constraint wpmt_1
foreign key (metric_id)
references GWL.d_WAP_COMP_metric (metric_id);       

--Staging hour fact table
create table GWL.stg_WAP_COMP_hr (
 msmt_id		   integer	  not null,
 orig_WAP_COMP_id            integer        not null,
 orig_Server_id		   integer	not null,
 Sv_Version         	   varchar(254)   not null,
 orig_Appl_id		   integer	not null,
 orig_host_id              integer        not null,
 orig_metric_id            integer        not null,
 cdw_id			   integer        not null	,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

-----------------------------
-- Daily Fact Table: WAP_COMP 
-----------------------------

create table GWL.f_WAP_COMP_day (
 WAP_COMP_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	  not null,
 Appl_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (WAP_COMP_id,
       Server_id,
       Sv_Version_id,
       Appl_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_wpcp_day1 on GWL.f_WAP_COMP_day (WAP_COMP_id);
create index gwl.f_wpcp_day2 on GWL.f_WAP_COMP_day (Server_id);
create index gwl.f_wpcp_day3 on GWL.f_WAP_COMP_day (Sv_Version_id);
create index gwl.f_wpcp_day4 on GWL.f_WAP_COMP_day (Appl_id);
create index gwl.f_wpcp_day5 on GWL.f_WAP_COMP_day (host_id);
create index gwl.f_wpcp_day6 on GWL.f_WAP_COMP_day (metric_id);
create index gwl.f_wpcp_day7 on GWL.f_WAP_COMP_day (meas_date);

Alter table GWL.f_WAP_COMP_day
add constraint wpcp_2
foreign key (WAP_COMP_id)
references GWL.d_WAP_COMP (WAP_COMP_id);

Alter table GWL.f_WAP_COMP_day
add constraint serv_58
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_WAP_COMP_day
add constraint vers_58
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_WAP_COMP_day
add constraint appl_14
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_WAP_COMP_day
add constraint host_58
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_WAP_COMP_day
add constraint wpmt_2
foreign key (metric_id)
references GWL.d_WAP_COMP_metric (metric_id);        


-----------------------------
-- Weekly Fact Table: WAP_COMP 
-----------------------------

create table GWL.f_WAP_COMP_week (
 WAP_COMP_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	  not null,
 Appl_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (WAP_COMP_id,
       Server_id,
       Sv_Version_id, 
       Appl_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_wpcp_wk1 on GWL.f_WAP_COMP_week (WAP_COMP_id);
create index gwl.f_wpcp_wk2 on GWL.f_WAP_COMP_week (Server_id);
create index gwl.f_wpcp_wk3 on GWL.f_WAP_COMP_week (Sv_Version_id);
create index gwl.f_wpcp_wk4 on GWL.f_WAP_COMP_week (Appl_id);
create index gwl.f_wpcp_wk5 on GWL.f_WAP_COMP_week (host_id);
create index gwl.f_wpcp_wk6 on GWL.f_WAP_COMP_week (metric_id);
create index gwl.f_wpcp_wk7 on GWL.f_WAP_COMP_week (meas_date);

Alter table GWL.f_WAP_COMP_week
add constraint wpcp_3
foreign key (WAP_COMP_id)
references GWL.d_WAP_COMP (WAP_COMP_id);

Alter table GWL.f_WAP_COMP_week
add constraint serv_59
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_WAP_COMP_week
add constraint vers_59
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_WAP_COMP_week
add constraint appl_15
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_WAP_COMP_week
add constraint host_59
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_WAP_COMP_week
add constraint wpmt_3
foreign key (metric_id)
references GWL.d_WAP_COMP_metric (metric_id); 

-----------------------------
-- Monthly Fact Table: WAP_COMP 
-----------------------------

create table GWL.f_WAP_COMP_month (
 WAP_COMP_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	  not null,
 Appl_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (WAP_COMP_id,
       Server_id,
       Sv_Version_id,
       Appl_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_wpcp_mo1 on GWL.f_WAP_COMP_month (WAP_COMP_id);
create index gwl.f_wpcp_mo2 on GWL.f_WAP_COMP_month (Server_id);
create index gwl.f_wpcp_mo3 on GWL.f_WAP_COMP_month (Sv_Version_id);
create index gwl.f_wpcp_mo4 on GWL.f_WAP_COMP_month (Appl_id);
create index gwl.f_wpcp_mo5 on GWL.f_WAP_COMP_month (host_id);
create index gwl.f_wpcp_mo6 on GWL.f_WAP_COMP_month (metric_id);
create index gwl.f_wpcp_mo7 on GWL.f_WAP_COMP_month (meas_date);

Alter table GWL.f_WAP_COMP_month
add constraint wpcp_4
foreign key (WAP_COMP_id)
references GWL.d_WAP_COMP (WAP_COMP_id);

Alter table GWL.f_WAP_COMP_month
add constraint serv_60
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_WAP_COMP_month
add constraint vers_60
foreign key (Sv_version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_WAP_COMP_month
add constraint appl_16
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_WAP_COMP_month
add constraint host_60
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_WAP_COMP_month
add constraint wpmt_4
foreign key (metric_id)
references GWL.d_WAP_COMP_metric (metric_id);       

--------------------
--- WebLogic EJB 
--------------------

---------------------------------
-- Dimension Table: EJB Metric 
---------------------------------

create table GWL.d_EJB_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254) not null,
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- Translation table

create table GWL.t_EJB_metric (
  orig_metric_id 		INTEGER not null,
  metric_id			INTEGER,
  cdw_id 			INTEGER not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			VARCHAR(254) not null,
  met_units 			VARCHAR(254) not null,
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--SEQUENCE      

create sequence GWL.ejmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.ejmt_i1
no cascade before insert on GWL.d_EJB_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for GWL.ejmt_id_seq;

-----------------------------
-- Dimension Table: EJB 
-----------------------------

create table GWL.d_EJB (
 EJB_id     	           integer        not null,
 EJBName                varchar(254)   not null,
      primary key (EJB_id));

-- Translation table

create table GWL.t_EJB (
 orig_EJB_id            integer        not null,
 EJB_id			integer,
 cdw_id			   integer        not null,
 EJBName                varchar(254)   not null,
      primary key (orig_EJB_id,cdw_id)
      );

--SEQUENCE      

create sequence GWL.ejb_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.ejb_i1
no cascade before insert on GWL.d_EJB  
referencing new as n for each row mode db2sql
set n.EJB_id = nextval for GWL.ejb_id_seq;
      
-----------------------------
-- Hourly Fact Table: EJB 
-----------------------------

create table GWL.f_EJB_hour (
 EJB_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 Appl_id		   integer	not null,
 EJB_Comp_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (EJB_id,
       Server_id,
       Sv_Version_id,
       Appl_id,
       EJB_Comp_id,
       host_id, metric_id, 
       meas_hour)
       );

create index gwl.f_ejb_hr1 on GWL.f_EJB_hour (EJB_id);
create index gwl.f_ejb_hr2 on GWL.f_EJB_hour (Server_id);
create index gwl.f_ejb_hr3 on GWL.f_EJB_hour (Sv_Version_id);
create index gwl.f_ejb_hr4 on GWL.f_EJB_hour (Appl_id);
create index gwl.f_ejb_hr5 on GWL.f_EJB_hour (EJB_Comp_id);
create index gwl.f_ejb_hr6 on GWL.f_EJB_hour (host_id);
create index gwl.f_ejb_hr7 on GWL.f_EJB_hour (metric_id);
create index gwl.f_ejb_hr8 on GWL.f_EJB_hour (meas_hour);

Alter table GWL.f_EJB_hour
add constraint ejb_1
foreign key (EJB_id)
references GWL.d_EJB (EJB_id);

Alter table GWL.f_EJB_hour
add constraint serv_61
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_EJB_hour
add constraint vers_61
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_EJB_hour
add constraint appl_17
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_EJB_hour
add constraint ejbc_5
foreign key (EJB_Comp_id)
references GWL.d_EJB_Comp (EJB_Comp_id);

Alter table GWL.f_EJB_hour
add constraint host_61
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_EJB_hour
add constraint ejmt_1
foreign key (metric_id)
references GWL.d_EJB_metric (metric_id);       

--Staging hour fact table
create table GWL.stg_EJB_hr (
 msmt_id		   integer	  not null,
 orig_EJB_id            integer        not null,
 orig_Server_id		   integer	not null,
 Sv_Version		   varchar(254)	not null,
 orig_Appl_id		   integer	not null,
 orig_EJB_Comp_id		   integer	not null,
 orig_host_id              integer        not null,
 orig_metric_id            integer        not null,
 cdw_id			   integer        not null	,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

-----------------------------
-- Daily Fact Table: EJB 
-----------------------------

create table GWL.f_EJB_day (
 EJB_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 Appl_id		   integer	not null,
 EJB_Comp_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (EJB_id,
       Server_id,
       Sv_Version_id,
       Appl_id,
       EJB_Comp_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_ejb_day1 on GWL.f_EJB_day (EJB_id);
create index gwl.f_ejb_day2 on GWL.f_EJB_day (Server_id);
create index gwl.f_ejb_day3 on GWL.f_EJB_day (Sv_Version_id);
create index gwl.f_ejb_day4 on GWL.f_EJB_day (Appl_id);
create index gwl.f_ejb_day5 on GWL.f_EJB_day (EJB_Comp_id);
create index gwl.f_ejb_day6 on GWL.f_EJB_day (host_id);
create index gwl.f_ejb_day7 on GWL.f_EJB_day (metric_id);
create index gwl.f_ejb_day8 on GWL.f_EJB_day (meas_date);

Alter table GWL.f_EJB_day
add constraint ejb_2
foreign key (EJB_id)
references GWL.d_EJB (EJB_id);

Alter table GWL.f_EJB_day
add constraint serv_62
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_EJB_day
add constraint vers_62
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_EJB_day
add constraint appl_18
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_EJB_day
add constraint ejbc_6
foreign key (EJB_Comp_id)
references GWL.d_EJB_Comp (EJB_Comp_id);

Alter table GWL.f_EJB_day
add constraint host_62
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_EJB_day
add constraint ejmt_2
foreign key (metric_id)
references GWL.d_EJB_metric (metric_id);        


-----------------------------
-- Weekly Fact Table: EJB 
-----------------------------

create table GWL.f_EJB_week (
 EJB_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 Appl_id		   integer	not null,
 EJB_Comp_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (EJB_id,
	Server_id,
	Sv_Version_id,
	Appl_id,
	EJB_Comp_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_ejb_wk1 on GWL.f_EJB_week (EJB_id);
create index gwl.f_ejb_wk2 on GWL.f_EJB_week (Server_id);
create index gwl.f_ejb_wk3 on GWL.f_EJB_week (Sv_Version_id);
create index gwl.f_ejb_wk4 on GWL.f_EJB_week (Appl_id);
create index gwl.f_ejb_wk5 on GWL.f_EJB_week (EJB_Comp_id);
create index gwl.f_ejb_wk6 on GWL.f_EJB_week (host_id);
create index gwl.f_ejb_wk7 on GWL.f_EJB_week (metric_id);
create index gwl.f_ejb_wk8 on GWL.f_EJB_week (meas_date);

Alter table GWL.f_EJB_week
add constraint ejb_3
foreign key (EJB_id)
references GWL.d_EJB (EJB_id);

Alter table GWL.f_EJB_week
add constraint serv_63
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_EJB_week
add constraint vers_63
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_EJB_week
add constraint appl_19
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_EJB_week
add constraint ejbc_7
foreign key (EJB_Comp_id)
references GWL.d_EJB_Comp (EJB_Comp_id);

Alter table GWL.f_EJB_week
add constraint host_63
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_EJB_week
add constraint ejmt_3
foreign key (metric_id)
references GWL.d_EJB_metric (metric_id); 

-----------------------------
-- Monthly Fact Table: EJB 
-----------------------------

create table GWL.f_EJB_month (
 EJB_id                 integer        not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 Appl_id		   integer	not null,
 EJB_Comp_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (EJB_id,
	Server_id,
	Sv_Version_id,
	Appl_id,
	EJB_Comp_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_ejb_mo1 on GWL.f_EJB_month (EJB_id);
create index gwl.f_ejb_mo2 on GWL.f_EJB_month (Server_id);
create index gwl.f_ejb_mo3 on GWL.f_EJB_month (Sv_Version_id);
create index gwl.f_ejb_mo4 on GWL.f_EJB_month (Appl_id);
create index gwl.f_ejb_mo5 on GWL.f_EJB_month (EJB_Comp_id);
create index gwl.f_ejb_mo6 on GWL.f_EJB_month (host_id);
create index gwl.f_ejb_mo7 on GWL.f_EJB_month (metric_id);
create index gwl.f_ejb_mo8 on GWL.f_EJB_month (meas_date);

Alter table GWL.f_EJB_month
add constraint ejb_4
foreign key (EJB_id)
references GWL.d_EJB (EJB_id);

Alter table GWL.f_EJB_month
add constraint serv_64
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_EJB_month
add constraint vers_64
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_EJB_month
add constraint appl_20
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_EJB_month
add constraint ejbc_8
foreign key (EJB_Comp_id)
references GWL.d_EJB_Comp (EJB_Comp_id);

Alter table GWL.f_EJB_month
add constraint host_64
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_EJB_month
add constraint ejmt_4
foreign key (metric_id)
references GWL.d_EJB_metric (metric_id);       

--------------------
--- WebLogic Servlet 
--------------------

---------------------------------
-- Dimension Table: Servlet Metric 
---------------------------------

create table GWL.d_Servlet_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254) not null,
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- Translation table

create table GWL.t_Servlet_metric (
  orig_metric_id 		INTEGER not null,
  metric_id			INTEGER,
  cdw_id 			INTEGER not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			VARCHAR(254) not null,
  met_units 			VARCHAR(254) not null,
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--SEQUENCE      

create sequence GWL.slmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.slmt_i1
no cascade before insert on GWL.d_Servlet_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for GWL.slmt_id_seq;

-----------------------------
-- Dimension Table: Servlet 
-----------------------------

create table GWL.d_Servlet (
 Servlet_id     	           integer        not null,
 ServletName                varchar(254)   not null,
      primary key (Servlet_id));

-- Translation table

create table GWL.t_Servlet (
 orig_Servlet_id            integer        not null,
 Servlet_id		   integer,
 cdw_id			   integer        not null,
 ServletName                varchar(254)   not null,
      primary key (orig_Servlet_id,cdw_id)
      );

--SEQUENCE      

create sequence GWL.svlt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.svlt_i1
no cascade before insert on GWL.d_Servlet  
referencing new as n for each row mode db2sql
set n.Servlet_id = nextval for GWL.svlt_id_seq;
      
     
-----------------------------
-- Dimension Table:ContextPath 
-----------------------------

create table GWL.d_sl_ContextPath (
 ContextPath_id    	           integer        not null,
 ContextPath                   varchar(254)   not null,
      primary key (ContextPath_id));

--SEQUENCE      

create sequence GWL.ctpt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.ctpt_i1
no cascade before insert on GWL.d_sl_ContextPath 
referencing new as n for each row mode db2sql
set n.ContextPath_id = nextval for GWL.ctpt_id_seq;     
      
-----------------------------
-- Dimension Table: ServletPath 
-----------------------------

create table GWL.d_sl_ServletPath (
 ServletPath_id    	      integer        not null,
 ServletPath                   varchar(254)   not null,
      primary key (ServletPath_id));

--SEQUENCE      

create sequence GWL.svpt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger GWL.svpt_i1
no cascade before insert on GWL.d_sl_ServletPath 
referencing new as n for each row mode db2sql
set n.ServletPath_id = nextval for GWL.svpt_id_seq;     
      
-----------------------------
-- Hourly Fact Table: Servlet 
-----------------------------

create table GWL.f_Servlet_hour (
 Servlet_id                 integer        not null,
 ContextPath_id         	   integer        not null, 
 ServletPath_id          integer	  not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 Appl_id		   integer	not null,
 WAP_COMP_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (Servlet_id,
       ContextPath_id, ServletPath_id,
       Server_id,
       Sv_Version_id,
       Appl_id,
       WAP_COMP_id,
       host_id, metric_id, 
       meas_hour)
       );

create index gwl.f_svlt_hr1 on GWL.f_Servlet_hour (Servlet_id);
create index gwl.f_svlt_hr2 on GWL.f_Servlet_hour (ContextPath_id);
create index gwl.f_svlt_hr3 on GWL.f_Servlet_hour (ServletPath_id);
create index gwl.f_svlt_hr4 on GWL.f_Servlet_hour (Server_id);
create index gwl.f_svlt_hr5 on GWL.f_Servlet_hour (Sv_Version_id);
create index gwl.f_svlt_hr6 on GWL.f_Servlet_hour (Appl_id);
create index gwl.f_svlt_hr7 on GWL.f_Servlet_hour (WAP_COMP_id);
create index gwl.f_svlt_hr8 on GWL.f_Servlet_hour (host_id);
create index gwl.f_svlt_hr9 on GWL.f_Servlet_hour (metric_id);
create index gwl.f_svlt_hr10 on GWL.f_Servlet_hour (meas_hour);

Alter table GWL.f_Servlet_hour
add constraint svlt_1
foreign key (Servlet_id)
references GWL.d_Servlet (Servlet_id);

Alter table GWL.f_Servlet_hour
add constraint ctpt_1
foreign key (ContextPath_id)
references GWL.d_sl_ContextPath (ContextPath_id);

Alter table GWL.f_Servlet_hour
add constraint svpt_1
foreign key (ServletPath_id)
references GWL.d_sl_ServletPath (ServletPath_id);

Alter table GWL.f_Servlet_hour
add constraint serv_65
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Servlet_hour
add constraint vers_65
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_Servlet_hour
add constraint appl_21
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_Servlet_hour
add constraint wpcp_5
foreign key (WAP_COMP_id)
references GWL.d_WAP_COMP (WAP_COMP_id);

Alter table GWL.f_Servlet_hour
add constraint host_65
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Servlet_hour
add constraint slmt_1
foreign key (metric_id)
references GWL.d_Servlet_metric (metric_id);       

--Staging hour fact table
create table GWL.stg_Servlet_hr (
 msmt_id		   integer	  not null,
 orig_Servlet_id            integer        not null,
 ContextPath         	   varchar(254)   not null,
 ServletPath                varchar(254)   not null,
 orig_Server_id		   integer	  not null,
 Sv_Version                varchar(254)   not null,
 orig_Appl_id		   integer	  not null,
 orig_WAP_COMP_id		   integer	  not null,
 orig_host_id              integer        not null,
 orig_metric_id            integer        not null,
 cdw_id			   integer        not null	,
 meas_hour                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

-----------------------------
-- Daily Fact Table: Servlet 
-----------------------------

create table GWL.f_Servlet_day (
 Servlet_id                 integer        not null,
 ContextPath_id		   integer	  not null,
 ServletPath_id	           integer 	  not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 Appl_id		   integer	not null,
 WAP_COMP_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (Servlet_id,
       ContextPath_id, ServletPath_id,
       Server_id,
       Sv_Version_id,
       Appl_id,
       WAP_COMP_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_svlt_day1 on GWL.f_Servlet_day (Servlet_id);
create index gwl.f_svlt_day2 on GWL.f_Servlet_day (ContextPath_id);
create index gwl.f_svlt_day3 on GWL.f_Servlet_day (ServletPath_id);
create index gwl.f_svlt_day4 on GWL.f_Servlet_day (Server_id);
create index gwl.f_svlt_day5 on GWL.f_Servlet_day (Sv_Version_id);
create index gwl.f_svlt_day6 on GWL.f_Servlet_day (Appl_id);
create index gwl.f_svlt_day7 on GWL.f_Servlet_day (WAP_COMP_id);
create index gwl.f_svlt_day8 on GWL.f_Servlet_day (host_id);
create index gwl.f_svlt_day9 on GWL.f_Servlet_day (metric_id);
create index gwl.f_svlt_day10 on GWL.f_Servlet_day (meas_date);

Alter table GWL.f_Servlet_day
add constraint svlt_2
foreign key (Servlet_id)
references GWL.d_Servlet (Servlet_id);

Alter table GWL.f_Servlet_day
add constraint ctpt_2
foreign key (ContextPath_id)
references GWL.d_sl_ContextPath (ContextPath_id);

Alter table GWL.f_Servlet_day
add constraint svpt_2
foreign key (ServletPath_id)
references GWL.d_sl_ServletPath (ServletPath_id);

Alter table GWL.f_Servlet_day
add constraint serv_66
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Servlet_day
add constraint  vers_66
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_Servlet_day
add constraint appl_22
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_Servlet_day
add constraint wpcp_6
foreign key (WAP_COMP_id)
references GWL.d_WAP_COMP (WAP_COMP_id);

Alter table GWL.f_Servlet_day
add constraint host_66
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Servlet_day
add constraint slmt_2
foreign key (metric_id)
references GWL.d_Servlet_metric (metric_id);        


-----------------------------
-- Weekly Fact Table: Servlet 
-----------------------------

create table GWL.f_Servlet_week (
 Servlet_id                 integer        not null,
 ContextPath_id		   integer	  not null,
 ServletPath_id	           integer 	  not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 Appl_id		   integer	not null,
 WAP_COMP_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (Servlet_id,
       ContextPath_id, ServletPath_id, 
       Server_id,
       Sv_Version_id,
       Appl_id,
       WAP_COMP_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_svlt_wk1 on GWL.f_Servlet_week (Servlet_id);
create index gwl.f_svlt_wk2 on GWL.f_Servlet_week (ContextPath_id);
create index gwl.f_svlt_wk3 on GWL.f_Servlet_week (ServletPath_id);
create index gwl.f_svlt_wk4 on GWL.f_Servlet_week (Server_id);
create index gwl.f_svlt_wk5 on GWL.f_Servlet_week (Sv_Version_id);
create index gwl.f_svlt_wk6 on GWL.f_Servlet_week (Appl_id);
create index gwl.f_svlt_wk7 on GWL.f_Servlet_week (WAP_COMP_id);
create index gwl.f_svlt_wk8 on GWL.f_Servlet_week (host_id);
create index gwl.f_svlt_wk9 on GWL.f_Servlet_week (metric_id);
create index gwl.f_svlt_wk10 on GWL.f_Servlet_week (meas_date);

Alter table GWL.f_Servlet_week
add constraint svlt_3
foreign key (Servlet_id)
references GWL.d_Servlet (Servlet_id);

Alter table GWL.f_Servlet_week
add constraint ctpt_3
foreign key (ContextPath_id)
references GWL.d_sl_ContextPath (ContextPath_id);

Alter table GWL.f_Servlet_week
add constraint svpt_3
foreign key (ServletPath_id)
references GWL.d_sl_ServletPath (ServletPath_id);

Alter table GWL.f_Servlet_week
add constraint serv_67
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Servlet_week
add constraint vers_67
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_Servlet_week
add constraint appl_23
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_Servlet_week
add constraint wpcp_7
foreign key (WAP_COMP_id)
references GWL.d_WAP_COMP (WAP_COMP_id);

Alter table GWL.f_Servlet_week
add constraint host_67
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Servlet_week
add constraint slmt_3
foreign key (metric_id)
references GWL.d_Servlet_metric (metric_id); 

-----------------------------
-- Monthly Fact Table: Servlet 
-----------------------------

create table GWL.f_Servlet_month (
 Servlet_id                 integer        not null,
 ContextPath_id		   integer	  not null,
 ServletPath_id	           integer 	  not null,
 Server_id		   integer	not null,
 Sv_Version_id		   integer	not null,
 Appl_id		   integer	not null,
 WAP_COMP_id		   integer	not null,
 host_id                   integer        not null,
 metric_id                 integer        not null,
 meas_date                 timestamp      not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
        primary key (Servlet_id,
       ContextPath_id, ServletPath_id, 
       Server_id,
       Sv_Version_id,
       Appl_id,
       WAP_COMP_id,
       host_id, metric_id, 
       meas_date)
       );

create index gwl.f_svlt_mo1 on GWL.f_Servlet_month (Servlet_id);
create index gwl.f_svlt_mo2 on GWL.f_Servlet_month (ContextPath_id);
create index gwl.f_svlt_mo3 on GWL.f_Servlet_month (ServletPath_id);
create index gwl.f_svlt_mo4 on GWL.f_Servlet_month (Server_id);
create index gwl.f_svlt_mo5 on GWL.f_Servlet_month (Sv_Version_id);
create index gwl.f_svlt_mo6 on GWL.f_Servlet_month (Appl_id);
create index gwl.f_svlt_mo7 on GWL.f_Servlet_month (WAP_COMP_id);
create index gwl.f_svlt_mo8 on GWL.f_Servlet_month (host_id);
create index gwl.f_svlt_mo9 on GWL.f_Servlet_month (metric_id);
create index gwl.f_svlt_mo10 on GWL.f_Servlet_month (meas_date);

Alter table GWL.f_Servlet_month
add constraint svlt_4
foreign key (Servlet_id)
references GWL.d_Servlet (Servlet_id);

Alter table GWL.f_Servlet_month
add constraint ctpt_4
foreign key (ContextPath_id)
references GWL.d_sl_ContextPath (ContextPath_id);

Alter table GWL.f_Servlet_month
add constraint svpt_4
foreign key (ServletPath_id)
references GWL.d_sl_ServletPath (ServletPath_id);

Alter table GWL.f_Servlet_month
add constraint serv_68
foreign key (Server_id)
references GWL.d_Server (Server_id);

Alter table GWL.f_Servlet_month
add constraint vers_68
foreign key (Sv_Version_id)
references GWL.d_Sv_Version (Sv_Version_id);

Alter table GWL.f_Servlet_month
add constraint appl_24
foreign key (Appl_id)
references GWL.d_Appl (Appl_id);

Alter table GWL.f_Servlet_month
add constraint wpcp_8
foreign key (WAP_COMP_id)
references GWL.d_WAP_COMP (WAP_COMP_id);

Alter table GWL.f_Servlet_month
add constraint host_68
foreign key (host_id)
references GWL.d_host (host_id);

Alter table GWL.f_Servlet_month
add constraint slmt_4
foreign key (metric_id)
references GWL.d_Servlet_metric (metric_id);       

